@@ -15,7 +15,7 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
-
+   
 
 #include <bootstrap/bootstrap.h>
 #include <webserver/request.h>
@@ -44,28 +44,22 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <manage/privileges.h>
 #include <system/index.h>
 #include <collaboration/index.h>
-#include <collaboration/url.h>
-#include <collaboration/direction.h>
-#include <styles/indext.h>
+#include <collaboration/settings.h>
 #include <styles/indexm.h>
 #include <styles/sheetm.h>
 #include <styles/view.h>
 #include <versification/index.h>
 #include <versification/system.h>
-#include <bible/manage.h>
-#include <bible/settings.h>
-#include <bible/book.h>
-#include <bible/chapter.h>
-#include <bible/import.h>
-#include <bible/abbreviations.h>
-#include <bible/order.h>
-#include <bible/css.h>
-#include <bible/editing.h>
+#include <bb/manage.h>
+#include <bb/settings.h>
+#include <bb/book.h>
+#include <bb/chapter.h>
+#include <bb/import.h>
+#include <bb/order.h>
+#include <bb/css.h>
 #include <compare/index.h>
 #include <jobs/index.h>
 #include <editverse/index.h>
-#include <editverse/load.h>
-#include <editverse/save.h>
 #include <navigation/update.h>
 #include <navigation/poll.h>
 #include <editusfm/index.h>
@@ -86,15 +80,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <editone/load.h>
 #include <editone/save.h>
 #include <editone/verse.h>
-#include <editold/index.h>
-#include <editold/load.h>
-#include <editold/save.h>
-#include <editold/offset.h>
-#include <editold/focus.h>
-#include <editoneold/index.h>
-#include <editoneold/load.h>
-#include <editoneold/save.h>
-#include <editoneold/verse.h>
 #include <search/all.h>
 #include <search/index.h>
 #include <search/replace.h>
@@ -127,7 +112,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <resource/index.h>
 #include <resource/organize.h>
 #include <resource/get.h>
-#include <resource/bible2resource.h>
+#include <resource/bb2resource.h>
 #include <resource/manage.h>
 #include <resource/print.h>
 #include <resource/download.h>
@@ -142,8 +127,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <resource/user1edit.h>
 #include <resource/user9view.h>
 #include <resource/user1view.h>
-#include <resource/biblegateway.h>
+#include <resource/bbgateway.h>
 #include <resource/studylight.h>
+#include <resource/unload.h>
 #include <mapping/index.h>
 #include <mapping/map.h>
 #include <notes/index.h>
@@ -162,8 +148,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <notes/verses.h>
 #include <notes/severity-1.h>
 #include <notes/severity-n.h>
-#include <notes/bible-1.h>
-#include <notes/bible-n.h>
+#include <notes/bb-1.h>
+#include <notes/bb-n.h>
 #include <notes/bulk.h>
 #include <notes/edit.h>
 #include <notes/summary.h>
@@ -183,18 +169,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <checks/suppress.h>
 #include <consistency/poll.h>
 #include <consistency/input.h>
-#include <xrefs/index.h>
-#include <xrefs/source.h>
-#include <xrefs/target.h>
-#include <xrefs/help.h>
-#include <xrefs/extract.h>
-#include <xrefs/interpret.h>
-#include <xrefs/translate.h>
-#include <xrefs/clear.h>
-#include <xrefs/insert.h>
-#include <xrefs/move.h>
-#include <xrefs/next.h>
-#include <webbible/search.h>
+#include <webbb/search.h>
 #include <developer/index.h>
 #include <paratext/index.h>
 #include <personalize/index.h>
@@ -213,6 +188,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <editor/select.h>
 #include <rss/feed.h>
 #include <assets/external.h>
+#include <system/logic.h>
 
 
 // Internal function to check whether a request coming from the browser is considered secure enough.
@@ -241,7 +217,7 @@ void bootstrap_index (void * webserver_request)
   string extension = filter_url_get_extension (request->get);
   string url = request->get.substr (1);
   
-  // Serve graphics, stylesheets, JavaScript, fonts.
+  // Serve graphics, stylesheets, JavaScript, fonts, with direct streaming for low memory usage.
   if (   (extension == "ico")
       || (extension == "png")
       || (extension == "gif")
@@ -253,7 +229,7 @@ void bootstrap_index (void * webserver_request)
       || (extension == "svg")
       || (extension == "map")
       ) {
-    http_serve_cache_file (request);
+    http_stream_file (request, true);
     return;
   }
 
@@ -264,7 +240,7 @@ void bootstrap_index (void * webserver_request)
 
   // Serve resource downloads.
   if ((extension == "sqlite") && (request->get.find (Database_Cache::fragment ()) != string::npos)) {
-    http_serve_cache_file (request);
+    http_stream_file (request, false);
     return;
   }
   
@@ -348,11 +324,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == bible_abbreviations_url ()) && browser_request_security_okay (request) && bible_abbreviations_acl (request)) {
-    request->reply = bible_abbreviations (request);
-    return;
-  }
-  
   if ((url == bible_order_url ()) && browser_request_security_okay (request) && bible_order_acl (request)) {
     request->reply = bible_order (request);
     return;
@@ -393,16 +364,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == editold_index_url ()) && browser_request_security_okay (request) && editold_index_acl (request)) {
-    request->reply = editold_index (request);
-    return;
-  }
-  
-  if ((url == editoneold_index_url ()) && browser_request_security_okay (request) && editoneold_index_acl (request)) {
-    request->reply = editoneold_index (request);
-    return;
-  }
-  
   if ((url == search_index_url ()) && browser_request_security_okay (request) && search_index_acl (request)) {
     request->reply = search_index (request);
     return;
@@ -418,11 +379,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == bible_editing_url ()) && browser_request_security_okay (request) && bible_editing_acl (request)) {
-    request->reply = bible_editing (request);
-    return;
-  }
-  
   if ((url == resource_bible2resource_url ()) && browser_request_security_okay (request) && resource_bible2resource_acl (request)) {
     request->reply = resource_bible2resource (request);
     return;
@@ -663,11 +619,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == xrefs_index_url ()) && browser_request_security_okay (request) && xrefs_index_acl (request)) {
-    request->reply = xrefs_index (request);
-    return;
-  }
-  
   if ((url == developer_index_url ()) && browser_request_security_okay (request) && developer_index_acl (request)) {
     request->reply = developer_index (request);
     return;
@@ -699,11 +650,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == styles_indext_url ()) && browser_request_security_okay (request) && styles_indext_acl (request)) {
-    request->reply = styles_indext (request);
-    return;
-  }
-  
   if ((url == styles_indexm_url ()) && browser_request_security_okay (request) && styles_indexm_acl (request)) {
     request->reply = styles_indexm (request);
     return;
@@ -863,13 +809,8 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == collaboration_url_url ()) && browser_request_security_okay (request) && collaboration_url_acl (request)) {
-    request->reply = collaboration_url (request);
-    return;
-  }
-  
-  if ((url == collaboration_direction_url ()) && browser_request_security_okay (request) && collaboration_direction_acl (request)) {
-    request->reply = collaboration_direction (request);
+  if ((url == collaboration_settings_url ()) && browser_request_security_okay (request) && collaboration_settings_acl (request)) {
+    request->reply = collaboration_settings (request);
     return;
   }
   
@@ -893,36 +834,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == xrefs_help_url ()) && browser_request_security_okay (request) && xrefs_help_acl (request)) {
-    request->reply = xrefs_help (request);
-    return;
-  }
-  
-  if ((url == xrefs_extract_url ()) && browser_request_security_okay (request) && xrefs_extract_acl (request)) {
-    request->reply = xrefs_extract (request);
-    return;
-  }
-  
-  if ((url == xrefs_interpret_url ()) && browser_request_security_okay (request) && xrefs_interpret_acl (request)) {
-    request->reply = xrefs_interpret (request);
-    return;
-  }
-  
-  if ((url == xrefs_translate_url ()) && browser_request_security_okay (request) && xrefs_translate_acl (request)) {
-    request->reply = xrefs_translate (request);
-    return;
-  }
-  
-  if ((url == xrefs_clear_url ()) && browser_request_security_okay (request) && xrefs_clear_acl (request)) {
-    request->reply = xrefs_clear (request);
-    return;
-  }
-  
-  if ((url == xrefs_insert_url ()) && browser_request_security_okay (request) && xrefs_insert_acl (request)) {
-    request->reply = xrefs_insert (request);
-    return;
-  }
-  
   if ((url == webbible_search_url ()) && browser_request_security_okay (request) && webbible_search_acl (request)) {
     request->reply = webbible_search (request);
     return;
@@ -959,6 +870,13 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
+#ifdef HAVE_CLIENT
+  if (extension == "tar") {
+    http_stream_file (request, false);
+    return;
+  }
+#endif
+  
   // Client calls.
   if (url == sync_setup_url ()) {
     request->reply = sync_setup (request);
@@ -978,7 +896,7 @@ void bootstrap_index (void * webserver_request)
   }
   if (extension == "sqlite") {
     if (filter_url_dirname (url) == filter_url_temp_dir ()) {
-      http_serve_cache_file (request);
+      http_stream_file (request, false);
       return;
     }
   }
@@ -1014,16 +932,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == editverse_load_url ()) && browser_request_security_okay (request) && editverse_load_acl (request)) {
-    request->reply = editverse_load (request);
-    return;
-  }
-  
-  if ((url == editverse_save_url ()) && browser_request_security_okay (request) && editverse_save_acl (request)) {
-    request->reply = editverse_save (request);
-    return;
-  }
-  
   if ((url == editone_load_url ()) && browser_request_security_okay (request) && editone_load_acl (request)) {
     request->reply = editone_load (request);
     return;
@@ -1039,26 +947,11 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == editoneold_load_url ()) && browser_request_security_okay (request) && editoneold_load_acl (request)) {
-    request->reply = editoneold_load (request);
-    return;
-  }
-  
-  if ((url == editoneold_save_url ()) && browser_request_security_okay (request) && editoneold_save_acl (request)) {
-    request->reply = editoneold_save (request);
-    return;
-  }
-  
   if ((url == editone_verse_url ()) && browser_request_security_okay (request) && editone_verse_acl (request)) {
     request->reply = editone_verse (request);
     return;
   }
 
-  if ((url == editoneold_verse_url ()) && browser_request_security_okay (request) && editoneold_verse_acl (request)) {
-    request->reply = editoneold_verse (request);
-    return;
-  }
-
   if ((url == edit_preview_url ()) && browser_request_security_okay (request) && edit_preview_acl (request)) {
     request->reply = edit_preview (request);
     return;
@@ -1109,26 +1002,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == editold_load_url ()) && browser_request_security_okay (request) && editold_load_acl (request)) {
-    request->reply = editold_load (request);
-    return;
-  }
-  
-  if ((url == editold_save_url ()) && browser_request_security_okay (request) && editold_save_acl (request)) {
-    request->reply = editold_save (request);
-    return;
-  }
-  
-  if ((url == editold_offset_url ()) && browser_request_security_okay (request) && editold_offset_acl (request)) {
-    request->reply = editold_offset (request);
-    return;
-  }
-
-  if ((url == editold_focus_url ()) && browser_request_security_okay (request) && editold_focus_acl (request)) {
-    request->reply = editold_focus (request);
-    return;
-  }
-
   if ((url == search_getids_url ()) && browser_request_security_okay (request) && search_getids_acl (request)) {
     request->reply = search_getids (request);
     return;
@@ -1163,7 +1036,12 @@ void bootstrap_index (void * webserver_request)
     request->reply = resource_get (request);
     return;
   }
-  
+
+  if ((url == resource_unload_url ()) && browser_request_security_okay (request) && resource_unload_acl (request)) {
+    request->reply = resource_unload (request);
+    return;
+  }
+
   if ((url == notes_poll_url ()) && browser_request_security_okay (request) && notes_poll_acl (request)) {
     request->reply = notes_poll (request);
     return;
@@ -1189,26 +1067,6 @@ void bootstrap_index (void * webserver_request)
     return;
   }
   
-  if ((url == xrefs_source_url ()) && browser_request_security_okay (request) && xrefs_source_acl (request)) {
-    request->reply = xrefs_source (request);
-    return;
-  }
-  
-  if ((url == xrefs_target_url ()) && browser_request_security_okay (request) && xrefs_target_acl (request)) {
-    request->reply = xrefs_target (request);
-    return;
-  }
-  
-  if ((url == xrefs_move_url ()) && browser_request_security_okay (request) && xrefs_move_acl (request)) {
-    request->reply = xrefs_move (request);
-    return;
-  }
-  
-  if ((url == xrefs_next_url ()) && browser_request_security_okay (request) && xrefs_next_acl (request)) {
-    request->reply = xrefs_next (request);
-    return;
-  }
-  
   if ((url == lexicon_definition_url ()) && browser_request_security_okay (request) && lexicon_definition_acl (request)) {
     request->reply = lexicon_definition (request);
     return;
