@@ -55,20 +55,26 @@ string changes_changes (void * webserver_request)
   Webserver_Request * request = (Webserver_Request *) webserver_request;
   Database_Modifications database_modifications;
   
-
-  bool touch = request->session_logic ()->touchEnabled ();
   
-  
-  string page;
-  Assets_Header header = Assets_Header (translate("Changes"), request);
-  header.setStylesheet ();
-  header.addBreadCrumb (menu_logic_translate_menu (), menu_logic_translate_text ());
-  if (touch) header.jQueryTouchOn ();
-  page += header.run ();
-  Assets_View view;
-  
-  
-  string username = request->session_logic()->currentUser ();
+  // Handle AJAX call to load the summary of a change notification.
+  if (request->query.count ("load")) {
+    int identifier = convert_to_int (request->query["load"]);
+    string block;
+    Passage passage = database_modifications.getNotificationPassage (identifier);
+    string link = filter_passage_link_for_opening_editor_at (passage.book, passage.chapter, passage.verse);
+    string category = database_modifications.getNotificationCategory (identifier);
+    if (category == changes_personal_category ()) category = emoji_smiling_face_with_smiling_eyes ();
+    if (category == changes_bible_category ()) category = emoji_open_book ();
+    string modification = database_modifications.getNotificationModification (identifier);
+    block.append ("<div id=\"entry" + convert_to_string (identifier) + "\">\n");
+    block.append ("<a href=\"expand\">" + emoji_file_folder () + "</a>\n");
+    block.append ("<a href=\"remove\">" + emoji_wastebasket () + "</a>\n");
+    block.append (link + "\n");
+    block.append (category + "\n");
+    block.append (modification + "\n");
+    block.append ("</div>\n");
+    return block;
+  }
   
   
   // Handle AJAX call to remove a change notification.
@@ -100,10 +106,32 @@ string changes_changes (void * webserver_request)
   }
   
   
+  
+  string username = request->session_logic()->currentUser ();
+  bool touch = request->session_logic ()->touchEnabled ();
+  
+  
+  string page;
+  Assets_Header header = Assets_Header (translate("Changes"), request);
+  header.setStylesheet ();
+  header.addBreadCrumb (menu_logic_translate_menu (), menu_logic_translate_text ());
+  if (touch) header.jQueryTouchOn ();
+  page += header.run ();
+  Assets_View view;
+  
+
+  // The selected Bible, that is, the Bible for which to show the change notifications.
+  string selectedbible = request->query ["selectedbible"];
+  if (request->query.count ("selectbible")) {
+    selectedbible = request->query ["selectbible"];
+  }
+  view.set_variable ("selectedbible", selectedbible);
+
+  
   // Remove a user's personal changes notifications and their matching change notifications in the Bible.
   string matching = request->query ["matching"];
   if (!matching.empty ()) {
-    vector <int> ids = database_modifications.clearNotificationMatches (username, matching, changes_bible_category ());
+    vector <int> ids = database_modifications.clearNotificationMatches (username, matching, changes_bible_category (), selectedbible);
 #ifdef HAVE_CLIENT
     // Client records deletions for sending to the Cloud.
     for (auto & id : ids) {
@@ -117,7 +145,7 @@ string changes_changes (void * webserver_request)
   
   // Remove all the personal change notifications.
   if (request->query.count ("personal")) {
-    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, changes_personal_category (), true);
+    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, changes_personal_category (), selectedbible);
     for (auto id : ids) {
       trash_change_notification (request, id);
       database_modifications.deleteNotification (id);
@@ -131,7 +159,7 @@ string changes_changes (void * webserver_request)
   
   // Remove all the Bible change notifications.
   if (request->query.count ("bible")) {
-    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, changes_bible_category (), true);
+    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, changes_bible_category (), selectedbible);
     for (auto id : ids) {
       trash_change_notification (request, id);
       database_modifications.deleteNotification (id);
@@ -146,7 +174,7 @@ string changes_changes (void * webserver_request)
   // Remove all the change notifications made by a certain user.
   if (request->query.count ("dismiss")) {
     string user = request->query ["dismiss"];
-    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, user, true);
+    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, user, selectedbible);
     for (auto id : ids) {
       trash_change_notification (request, id);
       database_modifications.deleteNotification (id);
@@ -159,29 +187,14 @@ string changes_changes (void * webserver_request)
   
   
   // Read the identifiers.
-  // Limit the number of results to keep the page reasonably fast even if there are many notifications.
-  vector <int> personal_ids = database_modifications.getNotificationPersonalIdentifiers (username, changes_personal_category (), true);
-  vector <int> bible_ids = database_modifications.getNotificationTeamIdentifiers (username, changes_bible_category (), true);
-  vector <int> ids = database_modifications.getNotificationIdentifiers (username, true);
-
-  
-  string textblock;
-  for (auto id : ids) {
-    Passage passage = database_modifications.getNotificationPassage (id);
-    string link = filter_passage_link_for_opening_editor_at (passage.book, passage.chapter, passage.verse);
-    string category = database_modifications.getNotificationCategory (id);
-    if (category == changes_personal_category ()) category = emoji_smiling_face_with_smiling_eyes ();
-    if (category == changes_bible_category ()) category = emoji_open_book ();
-    string modification = database_modifications.getNotificationModification (id);
-    textblock.append ("<div id=\"entry" + convert_to_string (id) + "\">\n");
-    textblock.append ("<a href=\"expand\" id=\"expand" + convert_to_string (id) + "\">" + emoji_file_folder () + "</a>\n");
-    textblock.append ("<a href=\"remove\" id=\"remove" + convert_to_string (id) + "\">" + emoji_wastebasket () + "</a>\n");
-    textblock.append (link + "\n");
-    textblock.append (category + "\n");
-    textblock.append (modification + "\n");
-    textblock.append ("</div>\n");
+  vector <int> notification_ids = database_modifications.getNotificationIdentifiers (username, selectedbible);
+  // Send the identifiers to the browser for download there.
+  string pendingidentifiers;
+  for (auto id : notification_ids) {
+    if (!pendingidentifiers.empty ()) pendingidentifiers.append (" ");
+    pendingidentifiers.append (convert_to_string (id));
   }
-  view.set_variable ("textblock", textblock);
+  view.set_variable ("pendingidentifiers", pendingidentifiers);
   
   
   string loading = "\"" + translate("Loading ...") + "\"";
@@ -190,9 +203,42 @@ string changes_changes (void * webserver_request)
   view.set_variable ("script", script);
 
   
+  // Add links to enable the user to show the change notifications for one Bible or for all Bibles.
+  vector <string> distinct_bibles = database_modifications.getNotificationDistinctBibles (username);
+  // Show the Bible selector if there's more than one distinct Bible.
+  bool show_bible_selector = distinct_bibles.size () > 1;
+  // Also show the Bible selector if there's no change notifications to display, yet there's at least one distinct Bible.
+  // This situation often occurs after clearing a Bible's notifications, so there's no notifications after clearing them,
+  // yet there's notifications for other Bibles.
+  // Showing the Bible selector in this situation enables the user to select the other Bible(s).
+  if (notification_ids.empty () && !distinct_bibles.empty ()) show_bible_selector = true;
+  // Show the Bible selector if needed.
+  if (show_bible_selector) {
+    // If there's more than one distinct Bible, add the "All Bibles" selector.
+    if (distinct_bibles.size () > 1) distinct_bibles.insert (distinct_bibles.begin(), "");
+    // Iterate over the Bibles and make them all selectable.
+    for (auto bible : distinct_bibles) {
+      string cssclass;
+      if (selectedbible == bible) cssclass = "active";
+      string name (bible);
+      if (name.empty ()) name = translate ("All Bibles");
+      view.add_iteration ("bibleselector", { make_pair ("selectbible", bible), make_pair ("biblename", name), make_pair ("class", cssclass) } );
+    }
+  }
+
+  
   // Enable links to dismiss categories of notifications depending on whether there's anything to dismiss.
-  if (!personal_ids.empty ()) view.enable_zone ("personal");
-  if (!bible_ids.empty ()) view.enable_zone ("bible");
+  // And give details about the number of changes.
+  vector <int> personal_ids = database_modifications.getNotificationTeamIdentifiers (username, changes_personal_category (), selectedbible);
+  if (!personal_ids.empty ()) {
+    view.enable_zone ("personal");
+    view.set_variable ("personalcount", convert_to_string (personal_ids.size ()));
+  }
+  vector <int> bible_ids = database_modifications.getNotificationTeamIdentifiers (username, changes_bible_category (), selectedbible);
+  if (!bible_ids.empty ()) {
+    view.enable_zone ("bible");
+    view.set_variable ("teamcount", convert_to_string (bible_ids.size ()));
+  }
   
   
   // Add links to clear the notifications from the individual contributors.
@@ -202,10 +248,12 @@ string changes_changes (void * webserver_request)
     if (category == changes_personal_category ()) continue;
     if (category == changes_bible_category ()) continue;
     string user = category;
-    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, user, true);
+    vector <int> ids = database_modifications.getNotificationTeamIdentifiers (username, user, selectedbible);
     if (!ids.empty ()) {
       dismissblock.append ("<p>* <a href=\"?dismiss=");
       dismissblock.append (user);
+      dismissblock.append ("&selectbible=");
+      dismissblock.append (selectedbible);
       dismissblock.append ("\">");
       dismissblock.append (user);
       dismissblock.append (": ");
@@ -222,7 +270,7 @@ string changes_changes (void * webserver_request)
   for (auto & category : categories) {
     if (category == changes_bible_category ()) continue;
     string user = category;
-    vector <int> personal_ids = database_modifications.getNotificationTeamIdentifiers (username, user, true);
+    vector <int> personal_ids = database_modifications.getNotificationTeamIdentifiers (username, user, selectedbible);
     string icon = category;
     if (category == changes_personal_category ()) icon = emoji_smiling_face_with_smiling_eyes ();
     if (!personal_ids.empty () && !bible_ids.empty ()) {
@@ -240,6 +288,18 @@ string changes_changes (void * webserver_request)
   view.set_variable ("interlinks", changes_interlinks (webserver_request, changes_changes_url ()));
   
   
+  // Whether to show the controls for dismissing the changes.
+  if (!notification_ids.empty ()) {
+    // Whether to put those controls at the bottom of the page, as the default location,
+    // or whether to put them at the top of the page.
+    if (request->database_config_user ()->getDismissChangesAtTop ()) {
+      view.enable_zone ("controlsattop");
+    } else {
+      view.enable_zone ("controlsatbottom");
+    }
+  }
+  
+  
   page += view.render ("changes", "changes");
   
   
