@@ -46,7 +46,7 @@
 
 // Helper function.
 // $user: The user whose changes are being processed.
-// $recipients: The users who opted to receive online notifications of any contributors.
+// $recipients: The users who opted for receiving online notifications of any contributor.
 void changes_process_identifiers (Webserver_Request * request,
                                   string user,
                                   vector <string> recipients,
@@ -356,19 +356,36 @@ void changes_modifications ()
     
     // Email the changes to the subscribed users.
     if (!email_changes.empty ()) {
+      // Split large emails up into parts.
+      // The size of the parts has been found by checking the maximum size that the emailer will send,
+      // then each part should remain well below that maximum size.
+      vector <string> bodies;
+      int counter = 0;
       string body;
       for (auto & line : email_changes) {
         body.append ("<div>");
         body.append (line);
         body.append ("</div>\n");
+        counter++;
+        if (counter >= 200) {
+          bodies.push_back (body);
+          body.clear ();
+          counter = 0;
+        }
       }
-      string subject = translate("Recent changes:") + " " + bible;
-      vector <string> users = request.database_users ()->getUsers ();
-      for (auto & user : users) {
-        if (request.database_config_user()->getUserBibleChangesNotification (user)) {
-          if (access_bible_read (&request, bible, user)) {
-            if (!client_logic_client_enabled ()) {
-              email_schedule (user, subject, body);
+      if (!body.empty ()) bodies.push_back (body);
+      for (size_t b = 0; b < bodies.size (); b++) {
+        string subject = translate("Recent changes:") + " " + bible;
+        if (bodies.size () > 1) {
+          subject.append (" (" + convert_to_string (b + 1) + "/" + convert_to_string (bodies.size ()) + ")");
+        }
+        vector <string> users = request.database_users ()->getUsers ();
+        for (auto & user : users) {
+          if (request.database_config_user()->getUserBibleChangesNotification (user)) {
+            if (access_bible_read (&request, bible, user)) {
+              if (!client_logic_client_enabled ()) {
+                email_schedule (user, subject, bodies[b]);
+              }
             }
           }
         }
