@@ -27,13 +27,9 @@
 #include <webserver/request.h>
 #include <locale/translate.h>
 #include <locale/logic.h>
-#include <pugixml/pugixml.hpp>
 #include <database/statistics.h>
 
 
-using namespace pugi;
-
-
 string changes_statistics_url ()
 {
   return "changes/statistics";
