@@ -40,6 +40,7 @@
 #include <checks/pairs.h>
 #include <checks/index.h>
 #include <checks/settings.h>
+#include <checks/french.h>
 #include <email/send.h>
 
 
@@ -101,6 +102,8 @@ void checks_run (string bible)
     }
   }
   bool check_space_end_verse = Database_Config_Bible::getCheckSpaceEndVerse (bible);
+  bool check_french_punctuation = Database_Config_Bible::getCheckFrenchPunctuation (bible);
+  bool check_french_citation_style = Database_Config_Bible::getCheckFrenchCitationStyle (bible);
 
   
   vector <int> books = request.database_bibles()->getBooks (bible);
@@ -144,7 +147,6 @@ void checks_run (string bible)
         Checks_Space::spaceBeforePunctuation (bible, book, chapter, verses_text);
       }
       
-      
       if (check_sentence_structure || check_paragraph_structure) {
         checks_sentences.initialize ();
         if (check_sentence_structure) checks_sentences.check (verses_text);
@@ -153,9 +155,7 @@ void checks_run (string bible)
                                        within_sentence_paragraph_markers,
                                        verses_paragraphs);
         }
-          
-          
-          
+        
         vector <pair<int, string>> results = checks_sentences.getResults ();
         for (auto result : results) {
           int verse = result.first;
@@ -164,9 +164,8 @@ void checks_run (string bible)
         }
       }
 
-
       if (check_well_formed_usfm) {
-        checks_usfm.initialize ();
+        checks_usfm.initialize (book, chapter);
         checks_usfm.check (chapterUsfm);
         checks_usfm.finalize ();
         vector <pair<int, string>>  results = checks_usfm.getResults ();
@@ -177,25 +176,31 @@ void checks_run (string bible)
         }
       }
 
-
       if (check_missing_punctuation_end_verse) {
         Checks_Verses::missingPunctuationAtEnd (bible, book, chapter, verses_text, center_marks, end_marks, disregards);
       }
       
-      
       if (check_patterns) {
         Checks_Verses::patterns (bible, book, chapter, verses_text, checking_patterns);
       }
-
       
       if (check_matching_pairs) {
-        Checks_Pairs::run (bible, book, chapter, verses_text, matching_pairs);
+        Checks_Pairs::run (bible, book, chapter, verses_text, matching_pairs, check_french_citation_style);
       }
       
-      
       if (check_space_end_verse) {
         Checks_Space::spaceEndVerse (bible, book, chapter, chapterUsfm);
       }
+      
+      if (check_french_punctuation) {
+        Checks_French::spaceBeforeAfterPunctuation (bible, book, chapter, verses_headings);
+        Checks_French::spaceBeforeAfterPunctuation (bible, book, chapter, verses_text);
+      }
+      
+      if (check_french_citation_style) {
+        Checks_French::citationStyle (bible, book, chapter, verses_paragraphs);
+      }
+      
     }
   }
   
@@ -206,7 +211,7 @@ void checks_run (string bible)
   for (auto hit : hits) {
     if (hit.bible == bible) {
       string passage = filter_passage_display_inline ({Passage ("", hit.book, hit.chapter, convert_to_string (hit.verse))});
-      string data = filter_string_sanitize_html (hit.data);
+      string data = escape_special_xml_characters (hit.data);
       string result = "<p>" + passage + " " + data + "</p>";
       emailBody.push_back (result);
     }
