@@ -354,6 +354,30 @@ void Database_Config_Bible::setCheckSpaceEndVerse (string bible, bool value)
 }
 
 
+bool Database_Config_Bible::getCheckFrenchPunctuation (string bible)
+{
+  return getBValue (bible, "check-french-punctuation", false);
+}
+void Database_Config_Bible::setCheckFrenchPunctuation (string bible, bool value)
+{
+  setBValue (bible, "check-french-punctuation", value);
+}
+
+
+const char * check_french_citation_style_key ()
+{
+  return "check-french-citation-style";
+}
+bool Database_Config_Bible::getCheckFrenchCitationStyle (string bible)
+{
+  return getBValue (bible, check_french_citation_style_key (), false);
+}
+void Database_Config_Bible::setCheckFrenchCitationStyle (string bible, bool value)
+{
+  setBValue (bible, check_french_citation_style_key (), value);
+}
+
+
 string Database_Config_Bible::getSprintTaskCompletionCategories (string bible)
 {
   return getValue (bible, "sprint-task-completion-categories", "Translate\nCheck\nHebrew/Greek\nDiscussions");
@@ -474,6 +498,16 @@ void Database_Config_Bible::setHyphenationSecondSet (string bible, string value)
 }
 
 
+string Database_Config_Bible::getEditorStylesheet (string bible)
+{
+  return getValue (bible, "editor-stylesheet", styles_logic_standard_sheet ().c_str());
+}
+void Database_Config_Bible::setEditorStylesheet (string bible, string value)
+{
+  setValue (bible, "editor-stylesheet", value);
+}
+
+
 string Database_Config_Bible::getExportStylesheet (string bible)
 {
   return getValue (bible, "export-stylesheet", styles_logic_standard_sheet ().c_str());
@@ -504,16 +538,6 @@ void Database_Config_Bible::setVerseMapping (string bible, string value)
 }
 
 
-string Database_Config_Bible::getBookAbbreviations (string bible)
-{
-  return getValue (bible, "book-abbreviations", "");
-}
-void Database_Config_Bible::setBookAbbreviations (string bible, string value)
-{
-  setValue (bible, "book-abbreviations", value);
-}
-
-
 bool Database_Config_Bible::getExportWebDuringNight (string bible)
 {
   return getBValue (bible, "export-web-during-night", false);
@@ -722,3 +746,42 @@ void Database_Config_Bible::setPublicFeedbackEnabled (string bible, bool value)
 {
   setBValue (bible, "public-feedback-enabled", value);
 }
+
+
+bool Database_Config_Bible::getReadFromGit (string bible)
+{
+  return getBValue (bible, "read-from-git", false);
+}
+void Database_Config_Bible::setReadFromGit (string bible, bool value)
+{
+  setBValue (bible, "read-from-git", value);
+}
+
+
+const char * send_changes_to_rss_key ()
+{
+  return "send-changes-to-rss";
+}
+bool Database_Config_Bible::getSendChangesToRSS (string bible)
+{
+  return getBValue (bible, send_changes_to_rss_key (), false);
+}
+void Database_Config_Bible::setSendChangesToRSS (string bible, bool value)
+{
+  setBValue (bible, send_changes_to_rss_key (), value);
+}
+
+
+const char * odt_space_after_verse_key ()
+{
+  return "odt-space-after-verse";
+}
+string Database_Config_Bible::getOdtSpaceAfterVerse (string bible)
+{
+  return getValue (bible, odt_space_after_verse_key (), " ");
+}
+void Database_Config_Bible::setOdtSpaceAfterVerse (string bible, string value)
+{
+  setValue (bible, odt_space_after_verse_key (), value);
+}
+
