@@ -272,24 +272,6 @@ void Database_Config_User::clear_cache ()
 // Named configuration functions.
 
 
-string Database_Config_User::getStylesheet ()
-{
-  string sheet = getValue ("stylesheet", styles_logic_standard_sheet ().c_str());
-  // If the stylesheet does not exist, take the first one available instead.
-  Database_Styles * database_styles = ((Webserver_Request *) webserver_request)->database_styles ();
-  vector <string> sheets = database_styles->getSheets();
-  if (find (sheets.begin (), sheets.end (), sheet) == sheets.end ()) {
-    sheet = sheets[0];
-    setStylesheet (sheet);
-  }
-  return sheet;
-}
-void Database_Config_User::setStylesheet (string sheet)
-{
-  setValue ("stylesheet", sheet);
-}
-
-
 string Database_Config_User::getBible ()
 {
   string bible = getValue ("bible", "");
@@ -876,26 +858,6 @@ void Database_Config_User::setPrintPassageTo (Passage value)
 }
 
 
-string Database_Config_User::getSourceXrefBible ()
-{
-  return getValue ("source-xref-bible", "");
-}
-void Database_Config_User::setSourceXrefBible (string bible)
-{
-  setValue ("source-xref-bible", bible);
-}
-
-
-string Database_Config_User::getTargetXrefBible ()
-{
-  return getValue ("target-xref-bible", "");
-}
-void Database_Config_User::setTargetXrefBible (string bible)
-{
-  setValue ("target-xref-bible", bible);
-}
-
-
 int Database_Config_User::getFocusedBook ()
 {
   return getIValue ("focused-book", 1);
@@ -1113,11 +1075,11 @@ void Database_Config_User::setDisplayBreadcrumbs (bool value)
 
 int Database_Config_User::getWorkspaceMenuFadeoutDelay ()
 {
-  return getIValue ("desktop-menu-fadeout-delay", 4);
+  return getIValue ("workspace-menu-fadeout-delay", 4);
 }
 void Database_Config_User::setWorkspaceMenuFadeoutDelay (int value)
 {
-  setIValue ("desktop-menu-fadeout-delay", value);
+  setIValue ("workspace-menu-fadeout-delay", value);
 }
 
 
@@ -1156,7 +1118,7 @@ bool Database_Config_User::getBasicInterfaceModeDefault ()
 #ifdef HAVE_CHROMEAPP
   return true;
 #endif
-  // The app running on a desktop or laptop have default to basic mode for a lower role.
+  // The app running on a workspace or laptop have default to basic mode for a lower role.
   Webserver_Request * request = (Webserver_Request *) webserver_request;
   int level = request->session_logic ()->currentLevel ();
   if (level <= Filter_Roles::manager ()) return true;
@@ -1205,72 +1167,6 @@ void Database_Config_User::setFastEditorSwitchingAvailable (bool value)
 }
 
 
-bool Database_Config_User::getDowngradeVisualEditors ()
-{
-  return getBValue ("downgrade-visual-editors", false);
-}
-void Database_Config_User::setDowngradeVisualEditors (bool value)
-{
-  setBValue ("downgrade-visual-editors", value);
-}
-
-
-bool Database_Config_User::getAllSoftwareUpdatesNotification ()
-{
-  return getBValue ("all-software-updates-notification", false);
-}
-bool Database_Config_User::getAllSoftwareUpdatesNotificationForUser (string username)
-{
-  return getBValueForUser (username, "all-software-updates-notification", false);
-}
-void Database_Config_User::setAllSoftwareUpdatesNotification (bool value)
-{
-  setBValue ("all-software-updates-notification", value);
-}
-
-
-bool Database_Config_User::getYourSoftwareUpdatesNotification ()
-{
-  return getBValue ("your-software-updates-notification", false);
-}
-bool Database_Config_User::getYourSoftwareUpdatesNotificationForUser (string username)
-{
-  return getBValueForUser (username, "your-software-updates-notification", false);
-}
-void Database_Config_User::setYourSoftwareUpdatesNotification (bool value)
-{
-  setBValue ("your-software-updates-notification", value);
-}
-
-
-vector <string> Database_Config_User::getLastMailedSoftwareVersionForUser (string username)
-{
-  return getListForUser (username, "last-mailed-software-version");
-}
-void Database_Config_User::setLastMailedSoftwareVersionForUser (string username, vector <string> values)
-{
-  setListForUser (username, "last-mailed-software-version", values);
-}
-
-
-vector <string> Database_Config_User::getConnectedClientsForUser (string username)
-{
-  return getListForUser (username, "connected-clients");
-}
-vector <string> Database_Config_User::getConnectedClients ()
-{
-  return getList ("connected-clients");
-}
-void Database_Config_User::setConnectedClients (vector <string> values)
-{
-  setList ("connected-clients", values);
-}
-void Database_Config_User::setConnectedClientsForUser (string username, vector <string> values)
-{
-  setListForUser (username, "connected-clients", values);
-}
-
-
 bool Database_Config_User::getIncludeRelatedPassages ()
 {
   return getBValue ("include-related-passages", false);
@@ -1339,3 +1235,78 @@ void Database_Config_User::setPrivilegeUseAdvancedModeForUser (string username,
 {
   setBValueForUser (username, privilege_use_advanced_mode_key (), value);
 }
+
+
+const char * privilege_delete_consultation_notes_key ()
+{
+  return "privilege-delete-consultation-notes";
+}
+bool Database_Config_User::getPrivilegeDeleteConsultationNotes ()
+{
+  return getBValue (privilege_delete_consultation_notes_key (), false);
+}
+void Database_Config_User::setPrivilegeDeleteConsultationNotes (bool value)
+{
+  setBValue (privilege_delete_consultation_notes_key (), value);
+}
+bool Database_Config_User::getPrivilegeDeleteConsultationNotesForUser (string username)
+{
+  return getBValueForUser (username, privilege_delete_consultation_notes_key (), false);
+}
+void Database_Config_User::setPrivilegeDeleteConsultationNotesForUser (string username, bool value)
+{
+  setBValueForUser (username, privilege_delete_consultation_notes_key (), value);
+}
+
+
+bool Database_Config_User::getDismissChangesAtTop ()
+{
+  return getBValue ("dismiss-changes-at-top", false);
+}
+void Database_Config_User::setDismissChangesAtTop (bool value)
+{
+  setBValue ("dismiss-changes-at-top", value);
+}
+
+
+const char * quick_note_edit_link_key ()
+{
+  return "quick-note-edit-link";
+}
+bool Database_Config_User::getQuickNoteEditLink ()
+{
+  return getBValue (quick_note_edit_link_key (), false);
+}
+void Database_Config_User::setQuickNoteEditLink (bool value)
+{
+  setBValue (quick_note_edit_link_key (), value);
+}
+
+
+const char * show_bible_in_notes_list_key ()
+{
+  return "show-bible-in-notes-list";
+}
+bool Database_Config_User::getShowBibleInNotesList ()
+{
+  return getBValue (show_bible_in_notes_list_key (), false);
+}
+void Database_Config_User::setShowBibleInNotesList (bool value)
+{
+  setBValue (show_bible_in_notes_list_key (), value);
+}
+
+
+const char * show_note_status_key ()
+{
+  return "show-note-status";
+}
+bool Database_Config_User::getShowNoteStatus ()
+{
+  return getBValue (show_note_status_key (), false);
+}
+void Database_Config_User::setShowNoteStatus (bool value)
+{
+  setBValue (show_note_status_key (), value);
+}
+
