@@ -32,8 +32,6 @@ public:
   void trim ();
   void remove (string username);
   void clear_cache ();
-  string getStylesheet ();
-  void setStylesheet (string sheet);
   string getBible ();
   void setBible (string bible);
   bool getSubscribeToConsultationNotesEditedByMe ();
@@ -144,10 +142,6 @@ public:
   Passage getPrintPassageTo ();
   Passage getPrintPassageToForUser (string user);
   void setPrintPassageTo (Passage value);
-  string getSourceXrefBible ();
-  void setSourceXrefBible (string bible);
-  string getTargetXrefBible ();
-  void setTargetXrefBible (string bible);
   int getFocusedBook ();
   void setFocusedBook (int book);
   int getFocusedChapter ();
@@ -204,20 +198,6 @@ public:
   void setSwipeActionsAvailable (bool value);
   bool getFastEditorSwitchingAvailable ();
   void setFastEditorSwitchingAvailable (bool value);
-  bool getDowngradeVisualEditors ();
-  void setDowngradeVisualEditors (bool value);
-  bool getAllSoftwareUpdatesNotification ();
-  bool getAllSoftwareUpdatesNotificationForUser (string username);
-  void setAllSoftwareUpdatesNotification (bool value);
-  bool getYourSoftwareUpdatesNotification ();
-  bool getYourSoftwareUpdatesNotificationForUser (string username);
-  void setYourSoftwareUpdatesNotification (bool value);
-  vector <string> getLastMailedSoftwareVersionForUser (string username);
-  void setLastMailedSoftwareVersionForUser (string username, vector <string> values);
-  vector <string> getConnectedClientsForUser (string username);
-  vector <string> getConnectedClients ();
-  void setConnectedClients (vector <string> values);
-  void setConnectedClientsForUser (string username, vector <string> values);
   bool getIncludeRelatedPassages ();
   void setIncludeRelatedPassages (bool value);
   int getFastSwitchVisualEditors ();
@@ -231,6 +211,18 @@ public:
   bool getPrivilegeUseAdvancedMode ();
   bool getPrivilegeUseAdvancedModeForUser (string username);
   void setPrivilegeUseAdvancedModeForUser (string username, bool value);
+  bool getPrivilegeDeleteConsultationNotes ();
+  void setPrivilegeDeleteConsultationNotes (bool value);
+  bool getPrivilegeDeleteConsultationNotesForUser (string username);
+  void setPrivilegeDeleteConsultationNotesForUser (string username, bool value);
+  bool getDismissChangesAtTop ();
+  void setDismissChangesAtTop (bool value);
+  bool getQuickNoteEditLink ();
+  void setQuickNoteEditLink (bool value);
+  bool getShowBibleInNotesList ();
+  void setShowBibleInNotesList (bool value);
+  bool getShowNoteStatus ();
+  void setShowNoteStatus (bool value);
 private:
   void * webserver_request;
   string file (string user);
