@@ -16,9 +16,6 @@ along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 */
 
-$ (document).ready (function (){
-});
-
 
 function debugLog (message)
 {
@@ -27,5 +24,7 @@ function debugLog (message)
     type: "GET",
     data: { log: message },
     cache: false,
+    async: false
   });
 }
+
