@@ -35,9 +35,8 @@
 #include <dialog/list.h>
 #include <ipc/focus.h>
 #include <menu/logic.h>
-#include <bible/logic.h>
+#include <bb/logic.h>
 #include <config/globals.h>
-#include <editold/index.h>
 
 
 string edit_index_url ()
@@ -60,13 +59,6 @@ string edit_index (void * webserver_request)
   Webserver_Request * request = (Webserver_Request *) webserver_request;
   
   
-  if (request->database_config_user ()->getDowngradeVisualEditors ()) {
-    // Redirect to deprecated editor.
-    redirect_browser (webserver_request, editold_index_url ());
-    return "";
-  }
-  
-  
   bool touch = request->session_logic ()->touchEnabled ();
 
   
@@ -132,13 +124,13 @@ string edit_index (void * webserver_request)
   int verticalCaretPosition = request->database_config_user ()->getVerticalCaretPosition ();
   string script =
   "var editorChapterLoaded = '" + locale_logic_text_loaded () + "';\n"
+  "var editorWillSave = '" + locale_logic_text_will_save () + "';\n"
   "var editorChapterSaving = '" + locale_logic_text_saving () + "';\n"
   "var editorChapterSaved = '" + locale_logic_text_saved () + "';\n"
   "var editorChapterRetrying = '" + locale_logic_text_retrying () + "';\n"
   "var editorChapterReformat = '" + locale_logic_text_reformat () + "';\n"
   "var editorWriteAccess = true;\n"
-  "var verticalCaretPosition = " + convert_to_string (verticalCaretPosition) + ";\n"
-  "var unsentBibleDataTimeoutWarning = '" + bible_logic_unsent_unreceived_data_warning (false) + "';\n";
+  "var verticalCaretPosition = " + convert_to_string (verticalCaretPosition) + ";\n";
   config_logic_swipe_enabled (webserver_request, script);
   view.set_variable ("script", script);
   
