@@ -52,8 +52,6 @@ $ (document).ready (function ()
       }
     });
   }
-  
-  if (unsentBibleDataTimeoutWarning) notifyItError (unsentBibleDataTimeoutWarning);
 
   $ ("#editor").on ("click", editorNoteCitationClicked);
 });
@@ -300,6 +298,7 @@ function editorContentChanged ()
 {
   if (!editorWriteAccess) return;
   editorTextChanged = true;
+  editorStatus (editorWillSave);
   editorContentChangedTimeoutStart ();
 }
 
@@ -525,6 +524,7 @@ function editorActiveStylesFeedback ()
 function editorSelectiveNotification (message)
 {
   if (message == editorChapterLoaded) return;
+  if (message == editorWillSave) return;
   if (message == editorChapterSaving) return;
   if (message == editorChapterSaved) return;
   if (message == editorChapterReformat) return;
