@@ -25,6 +25,7 @@
 #include <ipc/focus.h>
 #include <editor/usfm2html.h>
 #include <access/bible.h>
+#include <database/config/bible.h>
 
 
 string edit_position_url ()
@@ -57,7 +58,7 @@ string edit_position (void * webserver_request)
   int chapter = convert_to_int (request->query ["chapter"]);
   
   
-  string stylesheet = request->database_config_user()->getStylesheet ();
+  string stylesheet = Database_Config_Bible::getEditorStylesheet (bible);
   string usfm = request->database_bibles()->getChapter (bible, book, chapter);
   int verse = Ipc_Focus::getVerse (request);
 
