@@ -53,8 +53,6 @@ $ (document).ready (function ()
     });
   }
   
-  if (unsentBibleDataTimeoutWarning) notifyItError (unsentBibleDataTimeoutWarning);
-  
   $ ("#oneeditor").on ("click", oneEditorNoteCitationClicked);
 });
 
@@ -113,7 +111,8 @@ var oneverseEditorChangedTimeout;
 var oneverseLoadedText;
 var oneverseIdChapter = 0;
 var oneverseIdTimeout;
-var oneverseReload = false;
+var oneverseReloadFlag = false;
+var oneverseReloadPosition = undefined;
 var oneverseEditorTextChanged = false;
 var oneverseSaveAsync;
 var oneverseLoadAjaxRequest;
@@ -121,11 +120,11 @@ var oneverseSaving = false;
 var oneverseEditorWriteAccess = true;
 
 
-/*
- 
-Section for the new Passage event from the Navigator.
- 
-*/
+//
+//
+// Section for the new Passage event from the Navigator.
+//
+//
 
 
 function navigationNewPassage ()
@@ -141,28 +140,33 @@ function navigationNewPassage ()
   } else {
     return;
   }
-  oneverseEditorSaveVerse ();
-  oneverseReload = false;
+  oneverseEditorSaveVerse (true);
+  oneverseReloadFlag = false;
   oneverseEditorLoadVerse ();
 }
 
 
-/*
- 
-Section for editor load and save.
- 
-*/
+//
+//
+// Section for editor load and save.
+//
+//
 
 
 function oneverseEditorLoadVerse ()
 {
-  if ((oneverseNavigationBook != oneverseBook) || (oneverseNavigationChapter != oneverseChapter) || (oneverseNavigationVerse != oneverseVerse) || oneverseReload) {
+  if ((oneverseNavigationBook != oneverseBook) || (oneverseNavigationChapter != oneverseChapter) || (oneverseNavigationVerse != oneverseVerse) || oneverseReloadFlag) {
     oneverseBible = navigationBible;
     oneverseBook = oneverseNavigationBook;
     oneverseChapter = oneverseNavigationChapter;
     oneverseVerse = oneverseNavigationVerse;
     oneverseVerseLoading = oneverseNavigationVerse;
     oneverseIdChapter = 0;
+    if (oneverseReloadFlag) {
+      oneverseReloadPosition = oneverseCaretPosition ();
+    } else {
+      oneverseReloadPosition = undefined;
+    }
     if (oneverseLoadAjaxRequest && oneverseLoadAjaxRequest.readystate != 4) {
       oneverseLoadAjaxRequest.abort();
     }
@@ -200,7 +204,7 @@ function oneverseEditorLoadVerse ()
           quill.enable (oneverseEditorWriteAccess);
           // The browser may reformat the loaded html, so take the possible reformatted data for reference.
           oneverseLoadedText = $ (".ql-editor").html ();
-          oneverseReload = false;
+          oneverseReloadFlag = false;
           oneverseCaretMovedTimeoutStart ();
           // Create CSS for embedded styles.
           css4embeddedstyles ();
@@ -217,7 +221,7 @@ function oneverseEditorLoadVerse ()
         }
         if (response === false) {
           // Checksum or other error: Reload.
-          oneverseReload = true;
+          oneverseReloadFlag = true;
           oneverseEditorLoadVerse ();
         }
       },
@@ -275,11 +279,11 @@ function oneverseEditorSaveVerse (sync)
 }
 
 
-/*
- 
-Portion dealing with triggers for editor's content change.
- 
-*/
+//
+//
+// Portion dealing with triggers for editor's content change.
+//
+//
 
 
 var visualVerseEditorBlockingChange = false;
@@ -292,7 +296,7 @@ function visualVerseEditorTextChangeHandler (delta, oldContents, source)
   if (!delta.ops [0].retain) {
     quill.history.undo ();
   }
-
+  // Start save delay timer.
   oneverseEditorChanged ();
 }
 
@@ -301,6 +305,7 @@ function oneverseEditorChanged ()
 {
   if (!oneverseEditorWriteAccess) return;
   oneverseEditorTextChanged = true;
+  oneverseEditorStatus (oneverseEditorWillSave);
   if (oneverseEditorChangedTimeout) {
     clearTimeout (oneverseEditorChangedTimeout);
   }
@@ -308,11 +313,11 @@ function oneverseEditorChanged ()
 }
 
 
-/*
- 
-Section for user interface updates and feedback.
- 
-*/
+//
+//
+// Section for user interface updates and feedback.
+//
+//
 
 
 function oneverseEditorStatus (text)
@@ -341,17 +346,18 @@ function oneverseActiveStylesFeedback ()
 function oneverseEditorSelectiveNotification (message)
 {
   if (message == oneverseEditorVerseLoaded) return;
+  if (message == oneverseEditorWillSave) return;
   if (message == oneverseEditorVerseSaving) return;
   if (message == oneverseEditorVerseSaved) return;
   notifyItError (message);
 }
 
 
-/*
- 
-Section for polling the server for updates on the loaded chapter.
- 
-*/
+//
+//
+// Section for polling the server for updates on the loaded chapter.
+//
+//
 
 
 function oneverseIdPoller ()
@@ -374,7 +380,7 @@ function oneverseEditorPollId ()
       if (!oneverseSaving) {
         if (oneverseIdChapter != 0) {
           if (response != oneverseIdChapter) {
-            oneverseReload = true;
+            oneverseReloadFlag = true;
             oneverseEditorLoadVerse ();
             oneverseIdChapter = 0;
           }
@@ -389,11 +395,20 @@ function oneverseEditorPollId ()
 }
 
 
-/*
- 
-Section for getting and setting the caret position.
+//
+//
+// Section for getting and setting the caret position.
+//
+//
 
-*/
+
+function oneverseCaretPosition ()
+{
+  var position = undefined;
+  var range = quill.getSelection();
+  if (range) position = range.index;
+  return position;
+}
 
 
 function oneversePositionCaret ()
@@ -404,16 +419,22 @@ function oneversePositionCaret ()
 
 function oneversePositionCaretTimeout ()
 {
-  var position = 1 + oneverseVerse.length;
+  var position;
+  if (oneverseReloadPosition != undefined) {
+    position = oneverseReloadPosition;
+    oneverseReloadPosition = undefined;
+  } else {
+    position = 1 + oneverseVerse.length;
+  }
   quill.setSelection (position, 0, "silent");
 }
 
 
-/*
-
-Section for scrolling the editable portion into the center.
-
-*/
+//
+//
+// Section for scrolling the editable portion into the center.
+//
+//
 
 
 function oneverseScrollVerseIntoView ()
@@ -431,11 +452,11 @@ function oneverseScrollVerseIntoView ()
 }
 
 
-/*
-
-Section for the styles handling.
-
-*/
+//
+//
+// Section for the styles handling.
+//
+//
 
 
 function oneverseStylesButtonHandler ()
@@ -627,11 +648,11 @@ function oneverseApplyMonoStyle (style)
 }
 
 
-/*
- 
-Section with window events and their basic handlers.
- 
-*/
+//
+//
+// Section with window events and their basic handlers.
+//
+//
 
 
 function oneverseWindowKeyHandler (event)
@@ -649,11 +670,11 @@ function oneverseWindowKeyHandler (event)
 }
 
 
-/*
- 
-Section responding to a moved caret.
- 
-*/
+//
+//
+// Section responding to a moved caret.
+//
+//
 
 
 // Responds to a changed selection or caret.
@@ -682,11 +703,11 @@ function oneverseCaretMovedTimeoutStart ()
 }
 
 
-/*
- 
-Section for the notes.
- 
-*/
+//
+//
+// Section for the notes.
+//
+//
 
 
 var oneverseInsertedNotesCount = 0;
@@ -765,11 +786,11 @@ function oneEditorNoteCitationClicked (event)
 }
 
 
-/*
- 
-Section for navigating to another passage.
- 
-*/
+//
+//
+// Section for navigating to another passage.
+//
+//
 
 
 function oneVerseHtmlClicked (event)
@@ -815,11 +836,11 @@ function oneVerseHtmlClicked (event)
 }
 
 
-/*
- 
-Section for swipe navigation.
- 
-*/
+//
+//
+// Section for swipe navigation.
+//
+//
 
 
 function oneverseSwipeLeft (event)
