@@ -43,44 +43,6 @@ void editone_logic_prefix_html (string usfm, string stylesheet, string & html, s
 }
 
 
-void editone_old_logic_editable_html (string prefix_last_p_style, string usfm, string stylesheet, string & html, string & editable_last_p_style, string & editable_first_applied_p_style)
-{
-  if (!usfm.empty ()) {
-    Editor_Usfm2Html editor_usfm2html;
-    editor_usfm2html.load (usfm);
-    editor_usfm2html.stylesheet (stylesheet);
-    editor_usfm2html.run ();
-    html = editor_usfm2html.get ();
-    editable_last_p_style = editor_usfm2html.currentParagraphStyle;
-  }
-  
-  // If the first paragraph of the editable verse does not have a paragraph style applied,
-  // apply the last paragraph style of the prefix to the first paragraph of the focused verse.
-  // For example, html like this:
-  // <p><span class="v">7</span><span> </span><span>For Yahweh knows the way of the righteous,</span></p><p class="q2"><span>but the way of the wicked shall perish.</span></p>
-  // ... becomes like this:
-  // <p class="q1"><span class="v">7</span><span /><span>For Yahweh knows the way of the righteous,</span></p><p class="q2"><span>but the way of the wicked shall perish.</span></p>
-  if (!html.empty ()) {
-    if (!prefix_last_p_style.empty ()) {
-      xml_document document;
-      html = html2xml (html);
-      document.load_string (html.c_str(), parse_ws_pcdata_single);
-      xml_node p_node = document.first_child ();
-      string p_style = p_node.attribute ("class").value ();
-      if (p_style.empty ()) {
-        p_node.append_attribute ("class") = prefix_last_p_style.c_str ();
-        // Send the applied paragraph style to the browser,
-        // for later use when it saves the modified verse text.
-        editable_first_applied_p_style = prefix_last_p_style;
-      }
-      stringstream output;
-      document.print (output, "", format_raw);
-      html = output.str ();
-    }
-  }
-}
-
-
 void editone_logic_editable_html (string usfm, string stylesheet, string & html)
 {
   if (!usfm.empty ()) {
@@ -130,38 +92,19 @@ void editone_logic_suffix_html (string editable_last_p_style, string usfm, strin
 }
 
 
-string editone_old_logic_html_to_usfm (string stylesheet, string html, string applied_p_style)
-{
-  // If an initial style was added to the first paragraph, remove it again.
-  if (!applied_p_style.empty ()) {
-    // First do a html to xml conversion to avoid a mismatched tag error later in the save chain.
-    html = html2xml (html);
-    xml_document document;
-    document.load_string (html.c_str(), parse_ws_pcdata_single);
-    xml_node p_node = document.first_child ();
-    string p_style = p_node.attribute ("class").value ();
-    if (applied_p_style == p_style) {
-      p_node.remove_attribute ("class");
-    }
-    stringstream output;
-    document.print (output, "", format_raw);
-    html = output.str ();
-  }
-  
-  // Convert xml entities to normal characters.
-  html = filter_string_desanitize_html (html);
-  
-  // Convert the html back to USFM in the special way for editing one verse.
-  string usfm = editor_export_verse (stylesheet, html);
-  
-  return usfm;
-}
-
-
 string editone_logic_html_to_usfm (string stylesheet, string html)
 {
-  // Convert xml entities to normal characters.
-  html = filter_string_desanitize_html (html);
+  // It used to convert XML entities to normal characters.
+  // For example, it used to convert "&lt;" to "<".
+  // But doing this too early in the conversion chain led to the following problem:
+  // The XML parser was taking the "<" character as part of an XML element.
+  // It than didn't find the closing ">" marker, and then complained about parsing errors.
+  // And it dropped whatever followed the "<" marker.
+  // So it now no longer unescapes the XML special characters this early in the chain.
+  // It does it much later now, before saving the USFM that the converter produces.
+  
+  // Convert special spaces to normal ones.
+  html = any_space_to_standard_space (html);
   
   // Convert the html back to USFM in the special way for editing one verse.
   string usfm = editor_export_verse_quill (stylesheet, html);
