@@ -31,6 +31,7 @@
 #include <filter/text.h>
 #include <filter/archive.h>
 #include <filter/shell.h>
+#include <filter/usfm.h>
 #include <locale/translate.h>
 #include <styles/sheets.h>
 
@@ -45,8 +46,8 @@ void export_text_usfm_book (string bible, int book, bool log)
   
   
   // Filenames for text and usfm.
-  string usfmFilename = filter_url_create_path (usfmDirectory, Export_Logic::baseBookFileName (book) + ".usfm");
-  string textFilename = filter_url_create_path (textDirectory, Export_Logic::baseBookFileName (book) + ".txt");
+  string usfmFilename = filter_url_create_path (usfmDirectory, Export_Logic::baseBookFileName (bible, book) + ".usfm");
+  string textFilename = filter_url_create_path (textDirectory, Export_Logic::baseBookFileName (bible, book) + ".txt");
   
   
   Database_Bibles database_bibles;
@@ -79,6 +80,8 @@ void export_text_usfm_book (string bible, int book, bool log)
     
     // Get the USFM code for the current chapter.
     string chapter_data = database_bibles.getChapter (bible, book, chapter);
+    // Filter it.
+    chapter_data = usfm_remove_word_level_attributes (chapter_data);
     chapter_data = filter_string_trim (chapter_data);
     
     
