@@ -24,18 +24,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <config/libraries.h>
 
 
-bool filter_archive_can_zip ();
-string filter_archive_zip_file (string file);
 string filter_archive_zip_folder (string folder);
-bool filter_archive_can_unzip ();
+string filter_archive_zip_folder_shell_internal (string folder);
+string filter_archive_zip_folder_miniz_internal (string folder);
 string filter_archive_unzip (string file);
+string filter_archive_unzip_shell_internal (string file);
+string filter_archive_unzip_miniz_internal (string zipfile);
 string filter_archive_tar_gzip_file (string filename);
 string filter_archive_tar_gzip_folder (string folder);
 string filter_archive_untar_gzip (string file);
 string filter_archive_uncompress (string file);
 int filter_archive_is_archive (string file);
-string filter_archive_compress (string data);
-string filter_archive_decompress (string data);
+string filter_archive_microtar_pack (string tarball, string directory, vector <string> files);
+string filter_archive_microtar_unpack (string tarball, string directory);
 
 
 #endif
