@@ -27,7 +27,7 @@
 #include <database/jobs.h>
 #include <database/git.h>
 #include <database/config/general.h>
-#include <bible/logic.h>
+#include <bb/logic.h>
 #include <locale/translate.h>
 #include <rss/logic.h>
 
@@ -566,7 +566,7 @@ bool filter_git_resolve_conflicts (string repository, vector <string> & paths, s
   if (!unmerged_paths.empty ()) {
     vector <string> messages;
     string error;
-    filter_git_commit (repository, "", "Bibledit fixed merge conflicts", messages, error);
+    filter_git_commit (repository, "", translate ("Bibledit fixed merge conflicts"), messages, error);
   }
   
   // Done.
