@@ -306,65 +306,84 @@ bool filter_string_is_numeric (string s)
 }
 
 
-// C++ equivalent for PHP function htmlspecialchars.
-string filter_string_sanitize_html (string html)
+// This takes the five special XML characters and escapes them.
+// < : &lt;
+// & : &amp;
+// > : &gt;
+// " : &quot;
+// ' : &apos;
+string escape_special_xml_characters (string s)
 {
-  html = filter_string_str_replace ("&", "&amp;", html);
-  html = filter_string_str_replace ("\"", "&quot;", html);
-  html = filter_string_str_replace ("'", "&apos;", html);
-  html = filter_string_str_replace ("<", "&lt;", html);
-  html = filter_string_str_replace (">", "&gt;", html);
-  return html;
+  s = filter_string_str_replace ("&", "&amp;", s);
+  s = filter_string_str_replace ("\"", "&quot;", s);
+  s = filter_string_str_replace ("'", "&apos;", s);
+  s = filter_string_str_replace ("<", "&lt;", s);
+  s = filter_string_str_replace (">", "&gt;", s);
+  return s;
 }
 
 
-// Does the opposite of its counterpart.
-string filter_string_desanitize_html (string html)
+// This unescapes the five special XML characters.
+string unescape_special_xml_characters (string s)
 {
-  html = filter_string_str_replace ("&quot;", """", html);
-  html = filter_string_str_replace ("&amp;", "&", html);
-  html = filter_string_str_replace ("&apos;", "'", html);
-  html = filter_string_str_replace ("&lt;", "<", html);
-  html = filter_string_str_replace ("&gt;", ">", html);
-  html = filter_string_str_replace (unicode_non_breaking_space_entity (), " ", html);
-  html = filter_string_str_replace (non_breaking_space_utf8_c2a0 (), " ", html);
-  html = filter_string_str_replace (non_breaking_space_utf8_00a0 (), " ", html);
-  return html;
+  s = filter_string_str_replace ("&quot;", """", s);
+  s = filter_string_str_replace ("&amp;", "&", s);
+  s = filter_string_str_replace ("&apos;", "'", s);
+  s = filter_string_str_replace ("&lt;", "<", s);
+  s = filter_string_str_replace ("&gt;", ">", s);
+  return s;
 }
 
 
-// Returns a soft hyphen.
-string soft_hyphen ()
+// Converts other types of spaces to standard spaces.
+string any_space_to_standard_space (string s)
 {
-  // The "­" below is not an empty string, but the soft hyphen U+00AD.
-  return "­";
+  s = filter_string_str_replace (unicode_non_breaking_space_entity (), " ", s);
+  s = filter_string_str_replace (non_breaking_space_u00A0 (), " ", s);
+  return s;
 }
 
 
 // Returns a no-break space (NBSP) (x00A0).
-string non_breaking_space_utf8_00a0 ()
+string non_breaking_space_u00A0 ()
 {
-  unsigned char c[2] = { 0x00, 0xa0 };
-  return string (c, c + sizeof c / sizeof c[0]);
+  // Use C-style code.
+  return "\u00A0";
 }
 
 
-// Returns a no-break space (NBSP) (xC2A0).
-string non_breaking_space_utf8_c2a0 ()
+// Returns a soft hyphen.
+string soft_hyphen_u00AD ()
 {
-  unsigned char c[2] = { 0xc2, 0xa0 };
-  return string (c, c + sizeof c / sizeof c[0]);
+  // Soft hyphen U+00AD.
+  return "\u00AD";
 }
 
 
 // Returns an "en space", this is a nut, half an em space.
-string en_space ()
+string en_space_u2002 ()
 {
-  // The space below is U+2002.
-  return " ";
+  // U+2002.
+  return "\u2002";
 }
 
 
+// A "figure space".
+// A space to use in numbers.
+// It has the same width as the digits.
+// It does not break, it keeps the numbers together.
+string figure_space_u2007 ()
+{
+  return "\u2007";
+}
+
+
+// Returns a "narrow no-break space (x202F)
+string narrow_non_breaking_space_u202F ()
+{
+  return "\u202F";
+}
+
 // Returns the length of string s in unicode points, not in bytes.
 size_t unicode_string_length (string s)
 {
@@ -691,7 +710,7 @@ string filter_string_html2text (string html)
   text.append (html);
 
   // Replace xml entities with their text.
-  text = filter_string_desanitize_html (text);
+  text = unescape_special_xml_characters (text);
 
   while (text.find ("\n\n") != string::npos) {
     text = filter_string_str_replace ("\n\n", "\n", text);
