@@ -29,13 +29,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #ifndef HAVE_CLIENT
 #include <curl/curl.h>
 #endif
-#include "mbedtls/net.h"
-#include "mbedtls/debug.h"
-#include "mbedtls/ssl.h"
-#include "mbedtls/entropy.h"
-#include "mbedtls/ctr_drbg.h"
-#include "mbedtls/error.h"
-#include "mbedtls/certs.h"
+#include <mbedtls/net.h>
+#include <mbedtls/debug.h>
+#include <mbedtls/ssl.h>
+#include <mbedtls/entropy.h>
+#include <mbedtls/ctr_drbg.h>
+#include <mbedtls/error.h>
+#include <mbedtls/certs.h>
 #ifdef HAVE_WINDOWS
 #include <direct.h>
 #include <io.h>
@@ -81,8 +81,15 @@ vector <string> filter_url_scandir_internal (string folder)
     struct dirent * direntry;
     while ((direntry = readdir (dir)) != NULL) {
       string name = direntry->d_name;
+      // Exclude short-hand directory names.
       if (name == ".") continue;
       if (name == "..") continue;
+      // Exclude developer temporal files.
+      if (name == ".deps") continue;
+      if (name == ".dirstamp") continue;
+      // Exclude macOS files.
+      if (name == ".DS_Store") continue;
+      // Store the name.
       files.push_back (name);
     }
     closedir (dir);
@@ -1514,7 +1521,7 @@ void filter_url_ssl_tls_initialize ()
   // Random number generator.
   mbedtls_ctr_drbg_init (&filter_url_mbed_tls_ctr_drbg);
   mbedtls_entropy_init (&filter_url_mbed_tls_entropy);
-  const char *pers = "Bibledit Client";
+  const char *pers = "Client";
   ret = mbedtls_ctr_drbg_seed (&filter_url_mbed_tls_ctr_drbg, mbedtls_entropy_func, &filter_url_mbed_tls_entropy, (const unsigned char *) pers, strlen (pers));
   filter_url_display_mbed_tls_error (ret, NULL, false);
   // Wait until the trusted root certificates exist.
@@ -1647,3 +1654,14 @@ string filter_url_filename_unclean (string name)
   name = filter_string_str_replace ("___ve___", "|",  name);
   return name;
 }
+
+
+// Changes a Unix directory separator to a Windows one.
+// Works on Windows only.
+string filter_url_update_directory_separator_if_windows (string filename)
+{
+#ifdef HAVE_WINDOWS
+  filename = filter_string_str_replace ("/", DIRECTORY_SEPARATOR, filename);
+#endif
+  return filename;
+}
