@@ -27,7 +27,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <database/config/bible.h>
 #include <styles/logic.h>
 #include <webserver/request.h>
-#include <bible/logic.h>
+#include <bb/logic.h>
 #include <locale/translate.h>
 #include <developer/logic.h>
 
@@ -40,13 +40,6 @@ BookChapterData::BookChapterData (int book_in, int chapter_in, string data_in)
 }
 
 
-UsfmNote::UsfmNote (int offset_in, string data_in)
-{
-  offset = offset_in;
-  data = data_in;
-}
-
-
 // Returns the string $usfm as one long string.
 // $usfm may contain new lines, but the resulting long string won't.
 string usfm_one_string (string usfm)
@@ -189,6 +182,7 @@ vector <BookChapterData> usfm_import (string input, string stylesheet)
     string marker = usfm_get_marker (marker_or_text);
     if (marker != "") {
       // USFM marker found.
+      bool opener = usfm_is_opening_marker (marker_or_text);
       bool store_chapter_data = false;
       if (marker == "id") {
         retrieve_book_number_on_next_iteration = true;
@@ -209,8 +203,11 @@ vector <BookChapterData> usfm_import (string input, string stylesheet)
       Database_Styles_Item marker_data = database_styles.getMarkerData (stylesheet, marker);
       int type = marker_data.type;
       int subtype = marker_data.subtype;
-      if (styles_logic_starts_new_line_in_usfm (type, subtype)) {
-        chapter_data += "\n";
+      // Only opening markers can start on a new line. Closing markers never do.
+      if (opener) {
+        if (styles_logic_starts_new_line_in_usfm (type, subtype)) {
+          chapter_data += "\n";
+        }
       }
     }
     chapter_data += marker_or_text;
@@ -245,9 +242,10 @@ vector <int> usfm_get_verse_numbers (string usfm)
       else verse_numbers.push_back (convert_to_int (verse));
       extract_verse = false;
     }
-    if (marker_or_text.substr (0, 2) == "\\v") {
-      extract_verse = true;
-    }
+    if (marker_or_text.substr (0, 2) == usfm_marker_v ()) extract_verse = true;
+    string va_or_vp = marker_or_text.substr (0, 3);
+    if (va_or_vp == usfm_marker_va ()) extract_verse = false;
+    if (va_or_vp == usfm_marker_vp ()) extract_verse = false;
   }
   return verse_numbers;
 }
@@ -608,228 +606,6 @@ string usfm_get_closing_usfm (string text, bool embedded)
 }
 
 
-// This function extracts notes, e.g. cross references.
-// $usfm: Where to extract from.
-// $markers: Array of possible markers surrounding the notes.
-// It returns an array of array ($offset, $note).
-vector <UsfmNote> usfm_extract_notes (string usfm, const vector <string> & markers)
-{
-  set <string> openers;
-  set <string> closers;
-  for (string marker : markers) {
-    openers.insert (usfm_get_opening_usfm (marker));
-    closers.insert (usfm_get_closing_usfm (marker));
-  }
-
-  vector <string> markers_and_text = usfm_get_markers_and_text (usfm);
-
-  vector <UsfmNote> notes;
-  
-  bool within_note = false;
-  size_t running_offset = 0;
-  string running_note = "";
-
-  for (string item : markers_and_text) {
-    
-    if (openers.find (item) != openers.end ()) within_note = true;
-
-    // Caclulate the offset in the main text. 
-    // That means not to consider the length of the notes.
-    if (!within_note) {
-      running_offset += unicode_string_length (item);
-    }
-    
-    if (within_note) running_note += item;
-
-    if (closers.find (item) != closers.end()) {
-      notes.push_back (UsfmNote (running_offset, running_note));
-      running_note = "";
-      within_note = false;
-    }
-  }
-  
-  return notes;
-}
-
-
-// This function removes the notes from the USFM.
-// $usfm: Where to extract from.
-// $markers: Array of markers surrounding the notes.
-// It returns the USFM without the notes.
-string usfm_remove_notes (string usfm, const vector <string> & markers)
-{
-  vector <UsfmNote> notes = usfm_extract_notes (usfm, markers);
-  for (auto note : notes) {
-    string search = note.data;
-    usfm = filter_string_str_replace (search, "", usfm);
-  }
-  return usfm;
-}
-
-
-// This function inserts notes into USFM.
-// It replaces $search with $replace in the $notes.
-// $usfm: string where to insert the notes - it is assumed not to contain any notes yet.
-// $notes: object of offsets => notes.
-// $ratio: ratio to multiply the offsets with.
-// It returns the updated USFM.
-string usfm_insert_notes (string usfm, vector <UsfmNote> notes, float ratio)
-{
-  if (usfm.empty()) return usfm;
-  if (notes.empty()) return usfm;
-  
-  vector <string> markers = {"x", "f", "fe"};
-  
-  // Temporally extract existing notes.
-  vector <UsfmNote> existing = usfm_extract_notes (usfm, markers);
-
-  // Work with USFM without notes so that a note will not be inserted in another note.
-  usfm = usfm_remove_notes (usfm, markers);
-
-  // Calculate insertion positions before actually inserting the notes to avoid nested notes placement.
-  for (UsfmNote & note : notes) {
-    int position = note.offset;
-    position = convert_to_int (position * ratio);
-    position = usfm_get_new_note_position (usfm, position, 0);
-    note.offset = position;
-  }
-
-  // Add existing notes data.
-  notes.insert (notes.end(), existing.begin(), existing.end());
-
-  // Sort the notes such that the last one gets inserted first.
-  // This way inserting happens from the end of the USFM towards the start.
-  // Inserted text does not affect any insertion positions this way.
-  int highest_position = 0;
-  for (UsfmNote note : notes) {
-    int position = note.offset;
-    if (position > highest_position) {
-      highest_position = position;
-    }
-  }
-  vector <UsfmNote> notes2;
-  for (int i = highest_position; i >= 0; i--) {
-    for (UsfmNote note : notes) {
-      if (note.offset == i) {
-        notes2.push_back (note);
-      }
-    }
-  }
-
-  // Insert the notes into the USFM at the correct position.
-  for (UsfmNote note : notes2) {
-    int position = note.offset;
-    string text = note.data;
-    usfm.insert (position, text);
-  }
-
-  return usfm;
-}
-
-
-// This function moves a note one word back or forth in the USFM data.
-// $usfm: The USFM data.
-// $direction: The direction into which to move the note.
-// $number: The note number. Starts at 1.
-// Returns the updated USFM.
-string usfm_move_note (string usfm, int direction, int number)
-{
-  vector <string> markers = {"x", "f", "fe"};
-  vector <UsfmNote> notes = usfm_extract_notes (usfm, markers);
-  int key = number - 1;
-  if (key < 0) return usfm;
-  if (key >= (int)notes.size()) return usfm;
-  usfm = usfm_remove_notes (usfm, markers);
-  int position = notes[key].offset;
-  position += (direction * 3);
-  position = usfm_get_new_note_position (usfm, position, direction);
-  notes[key].offset = position;
-  usfm = usfm_insert_notes (usfm, notes, 1);
-  return usfm;
-}
-
-
-// This function gets a new position to insert a note.
-// $usfm: The USFM code to work with.
-// $position: Current position.
-// $direction: Direction where to go to find the new position:
-//   -1: Go back to the previous slot.
-//    0: Attempt current position, else take next slot.
-//    1: Go forward to the next slot.
-// The positions take the string as UTF8.
-size_t usfm_get_new_note_position (string usfm, size_t position, int direction)
-{
-  vector <string> words = filter_string_explode (usfm, ' ');
-
-  size_t length = 0;
-
-  vector <size_t> lengths;
-
-  for (string word : words) {
-
-    // Add length of item.
-    length += unicode_string_length (word);
-    
-    // Check whether at opening marker.
-    bool opening_marker = usfm_is_usfm_marker (word);
-    if (opening_marker) {
-      opening_marker = usfm_is_opening_marker (word);
-    }
-
-    // Don't create a slot for placing a note right after an opening marker.
-    if (!opening_marker) lengths.push_back (length);
-
-    // Add length of space.
-    length++;
-    
-  }
-  
-  bool found = false;
-  
-  if (direction > 0) {
-    // Take next position.
-    for (size_t length : lengths) {
-      if (found) continue;
-      if (length > position) {
-        position = length;
-        found = true;
-      }
-    }
-  } else if (direction < 0) {
-    // Take previous position.
-    vector <size_t> lengths_r (lengths.begin(), lengths.end());
-    reverse (lengths_r.begin(), lengths_r.end());
-    for (size_t length : lengths_r) {
-      if (found) continue;
-      if (length < position) {
-        position = length;
-        found = true;
-      }
-    }
-  } else {
-    // Take optimal position.
-    for (size_t length : lengths) {
-      if (found) continue;
-      if (length >= position) {
-        position = length;
-        found = true;
-      }
-    }
-  }
-  
-  if (!found) {
-    position = unicode_string_length (usfm);
-  }
-  
-  // Move a note to before punctuation.
-  set <string> punctuation = {".", ",", ";", ":", "?", "!"};
-  string character = unicode_string_substr (usfm, position - 1, 1);
-  if (punctuation.find (character) != punctuation.end()) position--;
-
-  return position;
-}
-
-
 // This function compares the $newtext with the $oldtext.
 // It returns an empty string if the difference is below the limit set for the Bible.
 // It returns a short message specifying the difference if it exceeds that limit.
@@ -1042,7 +818,7 @@ bool usfm_contains_empty_verses (string usfm)
   if (pos != string::npos) return true;
   pos = usfm.find ("\\v \\v");
   if (pos != string::npos) return true;
-  pos = usfm.find_last_of ("\\v");
+  pos = usfm.find_last_of (usfm_marker_v ());
   if (pos == usfm.length () - 1) return true;
   return false;
 }
@@ -1102,3 +878,81 @@ bool usfm_handle_verse_sequence (string verse, vector <int> & verses)
   }
   return false;
 }
+
+
+const char * usfm_marker_v ()
+{
+  return R"(\v)";
+}
+
+
+const char * usfm_marker_va ()
+{
+  return R"(\va)";
+}
+
+
+const char * usfm_marker_vp ()
+{
+  return R"(\vp)";
+}
+
+
+// This removes the word level attributes from $usfm.
+// See https://ubsicap.github.io/usfm/attributes/index.html
+// Within a character marker span,
+// an attributes list is separated from the text content by a vertical bar |.
+// Attributes are listed as pairs of name and corresponding value using the syntax:
+//   attribute = "value".
+// Example:
+//   \w gracious|lemma="grace"\w*
+string usfm_remove_word_level_attributes (string usfm) // Todo
+{
+  // Check there is a vertical bar at all in the input USFM.
+  // If it's not there, then the function is ready without much ado.
+  if (usfm.find ("|") != string::npos) {
+
+    // Flag whether a replacement was made.
+    bool keep_going = false;
+    
+    // In USFM 3.0 there's two character markers that support word level attributes:
+    vector <string> supported_character_markers = { "w", "fig" };
+    for (auto & marker : supported_character_markers) {
+
+      // Support multiple replacements.
+      size_t last_pos = 0;
+      do {
+      
+        // Set flag.
+        keep_going = false;
+
+        // The opener should be there.
+        size_t opener_pos = usfm.find (usfm_get_opening_usfm (marker), last_pos);
+        if (opener_pos == string::npos) continue;
+        last_pos = opener_pos + 1;
+
+        // The closer should be there too.
+        size_t closer_pos = usfm.find (usfm_get_closing_usfm (marker), last_pos);
+        if (closer_pos == string::npos) continue;
+
+        // The vertical bar should be between the opener and closer.
+        size_t bar_pos = usfm.find ("|", last_pos);
+        if (bar_pos == string::npos) continue;
+        if (bar_pos < opener_pos) continue;
+        
+        // There may be situations without the vertical bar.
+        if (bar_pos < closer_pos) {
+          // Remove the word level attribute.
+          usfm.erase (bar_pos, closer_pos - bar_pos);
+        }
+
+        // Set flag.
+        keep_going = true;
+
+      } while (keep_going);
+    }
+  }
+  
+  // Done.
+  return usfm;
+}
