@@ -31,8 +31,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <changes/changes.h>
 #include <workspace/index.h>
 #include <session/login.h>
-#include <bible/logic.h>
+#include <bb/logic.h>
 #include <filter/webview.h>
+#include <menu/logic.h>
 
 
 const char * index_index_url ()
@@ -53,10 +54,10 @@ string index_index (void * webserver_request)
   
   filter_webview_log_user_agent (request->user_agent);
   
-  Assets_Header header = Assets_Header ("Bibledit", webserver_request);
+  Assets_Header header = Assets_Header (translate ("Bibledit"), webserver_request);
   
   if (config_logic_demo_enabled ()) {
-    // The demo, when there's no active menu, forwards to a the active workspace.
+    // The demo, when there's no active menu, forwards to the active workspace.
     if (request->query.empty ()) {
       header.refresh (5, "/" + workspace_index_url ());
     }
@@ -65,10 +66,21 @@ string index_index (void * webserver_request)
   // Basic or advanced mode setting.
   string mode = request->query ["mode"];
   if (!mode.empty ()) {
-    bool basic = false;
-    if (mode == "basic") basic = true;
-    if (mode == "advanced") basic = false;
+    bool basic = (mode == "basic");
     request->database_config_user ()->setBasicInterfaceMode (basic);
+    menu_logic_tabbed_mode_save_json (webserver_request);
+  }
+  
+  // Upon app start, initialize the JSON for tabbed mode.
+  // It should be done during the setup phase.
+  // But in this case the setup phase does not provide user information.
+  // Here on this page, the user information is available.
+  static bool tabbed_json_initialized = false;
+  if (!tabbed_json_initialized) {
+    if (menu_logic_can_do_tabbed_mode ()) {
+      menu_logic_tabbed_mode_save_json (webserver_request);
+    }
+    tabbed_json_initialized = true;
   }
   
   // Normally a page does not show the expanded main menu.
@@ -82,7 +94,7 @@ string index_index (void * webserver_request)
   
   Assets_View view;
 
-  view.set_variable ("warning", bible_logic_unsent_unreceived_data_warning (true));
+  view.set_variable ("warning", bible_logic_unsent_unreceived_data_warning ());
   
   page += view.render ("index", "index");
   page += Assets_Page::footer ();
