@@ -56,7 +56,7 @@ bool index_listing_acl (void * webserver_request, string url)
 string index_listing (void * webserver_request, string url)
 {
   string page;
-  page = Assets_Page::header ("Bibledit", webserver_request);
+  page = Assets_Page::header (translate ("Bibledit"), webserver_request);
   // No breadcrumbs because the user can arrive here from more than one place.
   Assets_View view;
   url = filter_url_urldecode (url);
