@@ -26,6 +26,11 @@
 #include <sendreceive/changes.h>
 #include <sendreceive/files.h>
 #include <sendreceive/sendreceive.h>
+#include <journal/index.h>
+#include <pugixml/pugixml.hpp>
+
+
+using namespace pugi;
 
 
 // This returns true if the $entry can be filtered out from the Journal.
@@ -44,7 +49,9 @@ bool journal_logic_filter_entry (const string& entry)
   if (entry.find (sendreceive_files_sendreceive_text ()) != string::npos) return true;
   if (entry.find (sendreceive_files_up_to_date_text ()) != string::npos) return true;
   if (entry.find (sendreceive_sendreceive_sendreceive_text ()) != string::npos) return true;
-  if (entry.find (sendreceive_sendreceive_up_to_date_text ()) != string::npos) return true;
+  if (entry.find (sendreceive_sendreceive_send_text ()) != string::npos) return true;
+  if (entry.find (sendreceive_sendreceive_sendreceive_ready_text ()) != string::npos) return true;
+  if (entry.find (sendreceive_sendreceive_send_ready_text ()) != string::npos) return true;
   return false;
 }
 
@@ -53,3 +60,17 @@ string journal_logic_filtered_message ()
 {
   return translate ("Has been sending and receiving during the past hour");
 }
+
+
+string journal_logic_see_journal_for_progress ()
+{
+  xml_document document;
+  xml_node a_node = document.append_child ("a");
+  string href = "../";
+  href.append (journal_index_url ());
+  a_node.append_attribute ("href") = href.c_str ();
+  a_node.text () = translate ("See the Journal for progress.").c_str();
+  stringstream output;
+  document.print (output, "", format_default);
+  return output.str ();
+}
