@@ -36,6 +36,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #endif
 #include <sendreceive/logic.h>
 #include <ldap/logic.h>
+#include <locale/logic.h>
 
 
 bool bibledit_started = false;
@@ -61,11 +62,12 @@ const char * bibledit_get_network_port ()
 // To be called once during the lifetime of the app.
 // $package: The folder where the package data resides.
 // $webroot: The document root folder for the web server.
-void bibledit_initialize_library (const char * package, const char * webroot)
+void bibledit_initialize_library (const char * package, const char * webroot) // Todo
 {
   // Must initialize libcurl before any threads are started.
-#ifdef HAVE_CLIENT
-#else
+  // Only on the Cloud because it uses libcurl.
+  // The client does not use it.
+#ifdef HAVE_CLOUD
   curl_global_init (CURL_GLOBAL_ALL);
 #endif
   
@@ -97,7 +99,7 @@ void bibledit_initialize_library (const char * package, const char * webroot)
 #endif
 
 #ifdef HAVE_CLIENT
-  // Set local timezone offset in the library.
+  // Set local timezone offset in the library on Windows.
   int hours = 0;
 #ifdef HAVE_WINDOWS
   TIME_ZONE_INFORMATION tzi;
@@ -105,19 +107,19 @@ void bibledit_initialize_library (const char * package, const char * webroot)
   (void)dwRet;
   hours = 0 - (tzi.Bias / 60);
 #else
+  // Set local timezone offset in the library on Linux.
   time_t t = time (NULL);
   struct tm lt = {};
   localtime_r (&t, &lt);
-#ifndef HAVE_CHROMEAPP
-  // Chrome NaCl API does not have field "tm_gmtoff".
-  // To be fixed in a future version.
   hours = round (lt.tm_gmtoff / 3600);
-#endif
 #endif
   config_globals_timezone_offset_utc = hours;
   Database_Logs::log ("Timezone offset in hours: " + convert_to_string (hours));
 #endif
 
+  // Initialize obfuscation data.
+  locale_logic_obfuscate_initialize ();
+  
   // Initialize data in a thread.
   thread setup_thread = thread (setup_conditionally, package);
   setup_thread.detach ();
@@ -146,16 +148,8 @@ void bibledit_set_touch_enabled (bool enabled)
 }
 
 
-// Sets a global flag, so the library will quit at midnight.
-void bibledit_set_quit_at_midnight ()
-{
-  Database_Config_General::setJustStarted (true);
-  config_globals_quit_at_midnight = true;
-}
-
-
 // Start library.
-// Can be called multiple times during the lifetime of the app
+// Can be called multiple times during the lifetime of the app.
 void bibledit_start_library ()
 {
   // Repeating start guard.
@@ -171,6 +165,13 @@ void bibledit_start_library ()
   if (config_logic_demo_enabled ()) {
     config_globals_open_installation = true;
   }
+
+  
+#ifdef HAVE_CLOUD
+  // Indicate that the Cloud has started just now.
+  Database_Config_General::setJustStarted (true);
+#endif
+
   
   // Ignore SIGPIPE signal on Linux: When the browser cancels the request, it won't kill Bibledit.
   // On Windows, this is not needed.
@@ -187,7 +188,7 @@ void bibledit_start_library ()
   
   // Run the plain web server in a thread.
   config_globals_http_worker = new thread (http_server);
-
+  
   // Run the secure web server in a thread.
   config_globals_https_worker = new thread (https_server);
   
@@ -257,6 +258,14 @@ const char * bibledit_get_external_url ()
 }
 
 
+// Returns the pages the calling app should open.
+const char * bibledit_get_pages_to_open ()
+{
+  config_globals_pages_to_open = Database_Config_General::getMenuInTabbedViewJSON ();
+  return config_globals_pages_to_open.c_str ();
+}
+
+
 // The normal shutdown procedure works by connecting to the internal webservers,
 // and these connections in turn help with shutting down the listening internal webservers.
 // In case all the internal webservers no longer are able to accept connections,
