@@ -25,12 +25,12 @@ extern "C" {
   const char * bibledit_get_network_port ();
   void bibledit_initialize_library (const char * package, const char * webroot);
   void bibledit_set_touch_enabled (bool enabled);
-  void bibledit_set_quit_at_midnight ();
   void bibledit_start_library ();
   const char * bibledit_get_last_page ();
   bool bibledit_is_running ();
   const char * bibledit_is_synchronizing ();
   const char * bibledit_get_external_url ();
+  const char * bibledit_get_pages_to_open ();
   void bibledit_stop_library ();
   void bibledit_shutdown_library ();
   void bibledit_log (const char * message);
