@@ -31,12 +31,18 @@ string locale_logic_date_time (int seconds);
 map <string, string> locale_logic_localizations ();
 map <string, string> locale_logic_read_po (string file);
 
+string locale_logic_text_loaded ();
+string locale_logic_text_will_save ();
 string locale_logic_text_saving ();
 string locale_logic_text_saved ();
-string locale_logic_text_loaded ();
 string locale_logic_text_retrying ();
 string locale_logic_text_reformat ();
 string locale_logic_text_no_privileges_modify_book ();
 
+string locale_logic_space_get_name (string space, bool english);
+
+string locale_logic_deobfuscate (string value);
+void locale_logic_obfuscate_initialize ();
+
 
 #endif
