@@ -36,6 +36,7 @@
 #include <tasks/logic.h>
 #include <menu/logic.h>
 #include <assets/external.h>
+#include <locale/logic.h>
 
 
 const char * manage_exports_url ()
@@ -50,6 +51,14 @@ bool manage_exports_acl (void * webserver_request)
 }
 
 
+string space_href (string name)
+{
+  name = filter_string_str_replace ("-", "", name);
+  name = filter_string_str_replace (" ", "", name);
+  return name;
+}
+
+
 string manage_exports (void * webserver_request)
 {
   Webserver_Request * request = (Webserver_Request *) webserver_request;
@@ -275,8 +284,33 @@ string manage_exports (void * webserver_request)
     Database_State::setExport (bible, 0, Export_Logic::export_needed);
   }
   view.set_variable ("odtsecure", get_checkbox_status (Database_Config_Bible::getSecureOdtExport (bible)));
-                     
-                                          
+
+  
+  vector <string> spaces = { " ", non_breaking_space_u00A0 (), en_space_u2002 (), figure_space_u2007 (), narrow_non_breaking_space_u202F () };
+  if (request->query.count ("odtwhitespace")) {
+    string odtwhitespace = request->query ["odtwhitespace"];
+    for (auto space : spaces) {
+      // Work with non-localized, English, space names.
+      // Then it works across localizations.
+      string href = space_href (locale_logic_space_get_name (space, true));
+      if (odtwhitespace == href) {
+        Database_Config_Bible::setOdtSpaceAfterVerse (bible, space);
+      }
+    }
+  }
+  string space_setting = Database_Config_Bible::getOdtSpaceAfterVerse (bible);
+  for (auto space : spaces) {
+    string name = locale_logic_space_get_name (space, true);
+    string href = space_href (name);
+    string cssclass;
+    if (space == space_setting) {
+      cssclass = "active";
+    }
+    name = locale_logic_space_get_name (space, false);
+    view.add_iteration ("spaces", { make_pair ("space", href), make_pair ("class", cssclass), make_pair ("name", name) } );
+  }
+  
+  
   if (checkbox == "info") {
     Database_Config_Bible::setGenerateInfoDuringNight (bible, checked);
     Database_State::setExport (bible, 0, Export_Logic::export_needed);
@@ -382,16 +416,6 @@ string manage_exports (void * webserver_request)
   view.set_variable ("external", assets_external_logic_link_addon ());
   
   
-  bool zip = true;
-  if (!filter_archive_can_zip ()) zip = false;
-  if (!filter_archive_can_unzip ()) zip = false;
-  if (zip) {
-    view.enable_zone ("zip");
-  } else {
-    view.set_variable ("odtlink", client_logic_link_to_cloud (manage_exports_url (), translate ("Go to Bibledit Cloud for exports to OpenDocument.")));
-  }
-  
-
   page += view.render ("manage", "exports");
   page += Assets_Page::footer ();
   return page;
