@@ -47,7 +47,7 @@ string notes_bulk_url ()
 
 bool notes_bulk_acl (void * webserver_request)
 {
-  return Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  return Filter_Roles::access_control (webserver_request, Filter_Roles::translator ());
 }
 
 
@@ -99,6 +99,7 @@ string notes_bulk (void * webserver_request)
   bool unsubscribe = request->query.count ("unsubscribe");
   bool assign = request->query.count ("assign");
   bool unassign = request->query.count ("unassign");
+  bool unassignme = request->query.count ("unassignme");
   bool status = request->query.count ("status");
   bool severity = request->query.count ("severity");
   bool bible = request->query.count ("bible");
@@ -111,7 +112,7 @@ string notes_bulk (void * webserver_request)
   // This is done to remember them as long as this page is active.
   // Thus erroneous bulk operations on notes can be rectified somewhat easier.
   if (!subscribe && !unsubscribe && !assign && !unassign && !status && !severity && !bible && !erase) {
-    vector <int> identifiers = database_notes.selectNotes (bibles,
+    vector <int> identifiers = database_notes.select_notes_v12 (bibles,
                                               book,
                                               chapter,
                                               verse,
@@ -171,7 +172,7 @@ string notes_bulk (void * webserver_request)
     vector <string> assignees = database_noteassignment.assignees (user);
     if (in_array (assign, assignees)) {
       for (auto identifier : identifiers) {
-        if (!database_notes.isAssigned (identifier, assign)) {
+        if (!database_notes.is_assigned_v12 (identifier, assign)) {
           notes_logic.assignUser (identifier, assign);
         }
       }
@@ -184,19 +185,31 @@ string notes_bulk (void * webserver_request)
   if (unassign) {
     string unassign = request->query["unassign"];
     for (auto identifier : identifiers) {
-      if (database_notes.isAssigned (identifier, unassign)) {
+      if (database_notes.is_assigned_v12 (identifier, unassign)) {
         notes_logic.unassignUser (identifier, unassign);
       }
     }
     success = translate("The notes are no longer assigned to the user");
     Database_Logs::log ("Notes unassigned from user " + unassign + ": " + identifierlist);
   }
+
   
+  if (unassignme) {
+    string username = request->session_logic()->currentUser ();
+    for (auto identifier : identifiers) {
+      if (database_notes.is_assigned_v12 (identifier, username)) {
+        notes_logic.unassignUser (identifier, username);
+      }
+    }
+    success = translate("The notes are no longer assigned to you");
+    Database_Logs::log ("Notes unassigned from user " + username + ": " + identifierlist);
+  }
+
   
   if (status) {
     string status = request->query["status"];
     for (auto identifier : identifiers) {
-      if (database_notes.getRawStatus (identifier) != status) {
+      if (database_notes.get_raw_status_v12 (identifier) != status) {
         notes_logic.setStatus (identifier, status);
       }
     }
@@ -208,7 +221,7 @@ string notes_bulk (void * webserver_request)
   if (severity) {
     int severity = convert_to_int (request->query["severity"]);
     for (auto identifier : identifiers) {
-      if (database_notes.getRawSeverity (identifier) != severity) {
+      if (database_notes.get_raw_severity_v12 (identifier) != severity) {
         notes_logic.setRawSeverity (identifier, severity);
       }
     }
@@ -221,7 +234,7 @@ string notes_bulk (void * webserver_request)
     string bible = request->query["bible"];
     if (bible == notes_logic.generalBibleName ()) bible = "";
     for (auto identifier : identifiers) {
-      if (database_notes.getBible (identifier) != bible) {
+      if (database_notes.get_bible_v12 (identifier) != bible) {
         notes_logic.setBible (identifier, bible);
       }
     }
@@ -247,7 +260,13 @@ string notes_bulk (void * webserver_request)
   
   
   view.set_variable ("notescount", convert_to_string (identifiers.size()));
+
   
+  bool manager = Filter_Roles::access_control (webserver_request, Filter_Roles::manager ());
+  if (manager) {
+    view.enable_zone ("manager");
+  }
+
   
   view.set_variable ("success", success);
   view.set_variable ("error", error);
