@@ -78,13 +78,17 @@ string notes_verses (void * webserver_request)
         }
       }
     }
-    notes_logic.setPassages (id, passages);
-    redirect_browser (request, notes_actions_url () + "?id=" + convert_to_string (id));
-    return "";
+    if (passages.empty ()) {
+      error = translate ("The note should have one or more passages assigned.");
+    } else {
+      notes_logic.setPassages (id, passages);
+      redirect_browser (request, notes_actions_url () + "?id=" + convert_to_string (id));
+      return "";
+    }
   }
   
   
-  string verses = filter_passage_display_multiline (database_notes.getPassages (id));
+  string verses = filter_passage_display_multiline (database_notes.get_passages_v12 (id));
   view.set_variable ("verses", verses);
   
   
