@@ -27,8 +27,9 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 
 
 // Class for creating OpenDocument text documents.
-// At first the ODF Toolkit was used. But the Java code to generate this became too big for the compiler.
-// The other thing is that Java is slow as compared to this method employed here.
+// Initially the ODF Toolkit was used.
+// But the Java code to generate this became too big for the Java compiler.
+// The other thing is that Java is slow compared to the method below in C++.
 
 
 Odf_Text::Odf_Text (string bible_in)
@@ -474,8 +475,7 @@ void Odf_Text::initialize_styles_xml ()
           node.text ().set ("1");
         }
         {
-          xml_node node = text_p.append_child ("text:tab");
-          if (node) {}
+          text_p.append_child ("text:tab");
         }
         // Whether and how to put the date in the running headers.
         if (Database_Config_Bible::getDateInHeader (bible)) {
@@ -485,8 +485,7 @@ void Odf_Text::initialize_styles_xml ()
           node.text ().set ("");
         }
         {
-          xml_node node = text_p.append_child ("text:tab");
-          if (node) {}
+          text_p.append_child ("text:tab");
         }
         {
           xml_node node = text_p.append_child ("text:chapter");
@@ -504,8 +503,7 @@ void Odf_Text::initialize_styles_xml ()
           node.append_attribute ("text:outline-level") = "1";
         }
         {
-          xml_node node = text_p.append_child ("text:tab");
-          if (node) {}
+          text_p.append_child ("text:tab");
         }
         // Whether and how to put the date in the running headers.
         if (Database_Config_Bible::getDateInHeader (bible)) {
@@ -515,8 +513,7 @@ void Odf_Text::initialize_styles_xml ()
           node.text ().set ("");
         }
         {
-          xml_node node = text_p.append_child ("text:tab");
-          if (node) {}
+          text_p.append_child ("text:tab");
         }
         {
           xml_node node = text_p.append_child ("text:page-number");
@@ -562,7 +559,7 @@ void Odf_Text::addText (string text)
     }
     domElement = textSpanDomElement;
   }
-  domElement.text ().set (filter_string_sanitize_html (text).c_str());
+  domElement.text ().set (escape_special_xml_characters (text).c_str());
   
   // Update public paragraph text.
   currentParagraphContent += text;
@@ -842,7 +839,7 @@ void Odf_Text::placeTextInFrame (string text, string style, float fontsize, int
 
   xml_node textPDomElement = drawTextBoxDomElement.append_child ("text:p");
   textPDomElement.append_attribute ("text:style-name") = convertStyleName (style).c_str();
-  textPDomElement.text().set( filter_string_sanitize_html (text).c_str());
+  textPDomElement.text().set( escape_special_xml_characters (text).c_str());
 
   // File styles.xml contains the appropriate styles for this frame and text box and paragraph.
   // Create the styles once for the whole document.
@@ -952,10 +949,11 @@ void Odf_Text::addNote (string caller, string style, bool endnote)
   textNoteDomElement.append_attribute ("text:note-class") = noteclass.c_str();
 
   // The note citation, the 'caller' is normally in superscript in the OpenDocument.
-  // The default values of the application are used. The Bibledit stylesheet is not consulted.
+  // The default values of the application are used.
+  // The Bibledit stylesheet is not consulted.
   xml_node textNoteCitationDomElement = textNoteDomElement.append_child ("text:note-citation");
-  textNoteCitationDomElement.append_attribute ("text:label") = filter_string_sanitize_html (caller).c_str();
-  textNoteCitationDomElement.text().set( filter_string_sanitize_html (caller).c_str());
+  textNoteCitationDomElement.append_attribute ("text:label") = escape_special_xml_characters (caller).c_str();
+  textNoteCitationDomElement.text().set( escape_special_xml_characters (caller).c_str());
 
   xml_node textNoteBodyDomElement = textNoteDomElement.append_child ("text:note-body");
 
@@ -989,7 +987,7 @@ void Odf_Text::addNoteText (string text)
     }
     domElement = textSpanDomElement;
   }
-  domElement.text().set( filter_string_sanitize_html (text).c_str());
+  domElement.text().set( escape_special_xml_characters (text).c_str());
 }
 
 
@@ -1011,7 +1009,7 @@ void Odf_Text::newNamedHeading (string style, string text, bool hide)
   xml_node textHDomElement = officeTextDomNode.append_child ("text:h");
   textHDomElement.append_attribute ("text:style-name") = convertStyleName (style).c_str();
   textHDomElement.append_attribute ("text:outline-level") = "1";
-  textHDomElement.text().set(filter_string_sanitize_html (text).c_str());
+  textHDomElement.text().set(escape_special_xml_characters (text).c_str());
 
   // Heading style looks like this in styles.xml:
   // <style:style style:name="Heading_20_1" style:display-name="Heading 1" style:family="paragraph" style:parent-style-name="Heading" style:next-style-name="Text_20_body" style:default-outline-level="1" style:class="text">
