@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <access/logic.h>
 #include <access/bible.h>
 #include <dialog/list.h>
-#include <bible/logic.h>
+#include <bb/logic.h>
 #include <ipc/focus.h>
 #include <client/logic.h>
 
@@ -107,10 +107,21 @@ string personalize_index (void * webserver_request)
   }
 
   
-  // Visual Bible editor downgrading.
-  if (request->query.count ("editordowngrade")) {
-    bool state = request->database_config_user ()->getDowngradeVisualEditors ();
-    request->database_config_user ()->setDowngradeVisualEditors (!state);
+  // Whether to have a menu entry for the Changes in basic mode.
+  if (request->query.count ("showchanges")) {
+    bool state = request->database_config_user ()->getMenuChangesInBasicMode ();
+    state = !state;
+    request->database_config_user ()->setMenuChangesInBasicMode (state);
+    menu_logic_tabbed_mode_save_json (webserver_request);
+  }
+
+  
+  // Setting for whether to show the main menu in tabbed view in basic mode on phones and tablets.
+  if (request->query.count ("mainmenutabs")) {
+    bool state = Database_Config_General::getMenuInTabbedViewOn ();
+    state = !state;
+    Database_Config_General::setMenuInTabbedViewOn (state);
+    menu_logic_tabbed_mode_save_json (webserver_request);
   }
 
   
@@ -257,12 +268,12 @@ string personalize_index (void * webserver_request)
 
   
   // Workspace menu fade-out delay.
-  if (request->query.count ("desktopfadeoutdelay")) {
-    Dialog_Entry dialog_entry = Dialog_Entry ("index", translate("Please enter a value between 1 and 100 seconds, or 0 to disable"), convert_to_string (request->database_config_user ()->getWorkspaceMenuFadeoutDelay ()), "desktopfadeoutdelay", "");
+  if (request->query.count ("workspacefadeoutdelay")) {
+    Dialog_Entry dialog_entry = Dialog_Entry ("index", translate("Please enter a value between 1 and 100 seconds, or 0 to disable"), convert_to_string (request->database_config_user ()->getWorkspaceMenuFadeoutDelay ()), "workspacefadeoutdelay", "");
     page += dialog_entry.run ();
     return page;
   }
-  if (request->post.count ("desktopfadeoutdelay")) {
+  if (request->post.count ("workspacefadeoutdelay")) {
     int value = convert_to_int (request->post["entry"]);
     if ((value >= 0) && (value <= 100)) {
       request->database_config_user ()->setWorkspaceMenuFadeoutDelay (value);
@@ -270,7 +281,7 @@ string personalize_index (void * webserver_request)
       error = translate ("Incorrect fade-out delay in seconds");
     }
   }
-  view.set_variable ("desktopfadeoutdelay", convert_to_string (request->database_config_user ()->getWorkspaceMenuFadeoutDelay ()));
+  view.set_variable ("workspacefadeoutdelay", convert_to_string (request->database_config_user ()->getWorkspaceMenuFadeoutDelay ()));
 
   
   // Permissable relative changes in the two to four Bible editors.
@@ -318,8 +329,8 @@ string personalize_index (void * webserver_request)
   if (request->query.count (fastswitchusfmeditors)) {
     editors = request->query[fastswitchusfmeditors];
     if (editors.empty ()) {
-      Dialog_List dialog_list = Dialog_List ("index", translate("Which visual Bible editors to enable?"), "", "");
-      for (int i = 0; i < 3; i++) {
+      Dialog_List dialog_list = Dialog_List ("index", translate("Enable the USFM Bible editor?"), "", "");
+      for (int i = 0; i < 2; i++) {
         dialog_list.add_row (menu_logic_editor_settings_text (false, i), fastswitchusfmeditors, convert_to_string (i));
       }
       page += dialog_list.run ();
@@ -332,34 +343,6 @@ string personalize_index (void * webserver_request)
   view.set_variable (fastswitchusfmeditors, editors);
 
   
-  // The names of the two, three, or four Bible editors.
-  // The location of this code is important that it is after the editors have been enabled or disabled.
-  string chapter_editors, verse_editors;
-  for (int i = 0; i < 4; i++) {
-    bool visual = (i % 2);
-    bool chapter = (i <2);
-    if (menu_logic_editor_enabled (webserver_request, visual, chapter)) {
-      string label = menu_logic_editor_menu_text (webserver_request, visual, chapter);
-      if (chapter) {
-        if (!chapter_editors.empty ()) chapter_editors.append (", ");
-        chapter_editors.append (label);
-      } else {
-        if (!verse_editors.empty ()) verse_editors.append (", ");
-        verse_editors.append (label);
-      }
-    }
-  }
-  if (!chapter_editors.empty ()) view.enable_zone ("chaptereditors");
-  view.set_variable ("chaptereditors", chapter_editors);
-  if (!verse_editors.empty ()) view.enable_zone ("verseeditors");
-  view.set_variable ("verseeditors", verse_editors);
-
-  
-  // Whether to downgrade the visual Bible editors.
-  on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getDowngradeVisualEditors ());
-  view.set_variable ("editordowngrade", on_off);
-
-  
   // Whether to enable editing styles in the visual editors.
   on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getEnableStylesButtonVisualEditors ());
   view.set_variable ("enablestylesbutton", on_off);
@@ -393,14 +376,54 @@ string personalize_index (void * webserver_request)
 
   
   // Whether to have a menu entry for the Changes in basic mode.
-  if (request->query.count ("showchanges")) {
-    bool state = request->database_config_user ()->getMenuChangesInBasicMode ();
-    request->database_config_user ()->setMenuChangesInBasicMode (!state);
-  }
   on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getMenuChangesInBasicMode ());
   view.set_variable ("showchanges", on_off);
 
   
+  // Whether to put the controls for dismissing the change notificatios at the top of the page.
+  if (request->query.count ("dismisschangesattop")) {
+    bool state = request->database_config_user ()->getDismissChangesAtTop ();
+    request->database_config_user ()->setDismissChangesAtTop (!state);
+  }
+  on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getDismissChangesAtTop ());
+  view.set_variable ("dismisschangesattop", on_off);
+  
+  
+  // Setting for whether to show the main menu in tabbed view in basic mode on phones and tablets.
+  if (menu_logic_can_do_tabbed_mode ()) {
+    view.enable_zone ("tabs_possible");
+    on_off = styles_logic_off_on_inherit_toggle_text (Database_Config_General::getMenuInTabbedViewOn ());
+    view.set_variable ("mainmenutabs", on_off);
+  }
+
+  
+  // Whether to enable a quick link to edit the content of a consultation note.
+  if (request->query.count ("quickeditnotecontents")) {
+    bool state = request->database_config_user ()->getQuickNoteEditLink ();
+    request->database_config_user ()->setQuickNoteEditLink (!state);
+  }
+  on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getQuickNoteEditLink ());
+  view.set_variable ("quickeditnotecontents", on_off);
+
+  
+  // Whether the list of consultation notes shows the Bible the note refers to.
+  if (request->query.count ("showbibleinnoteslist")) {
+    bool state = request->database_config_user ()->getShowBibleInNotesList ();
+    request->database_config_user ()->setShowBibleInNotesList (!state);
+  }
+  on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getShowBibleInNotesList ());
+  view.set_variable ("showbibleinnoteslist", on_off);
+  
+  
+  // Whether to display the note status in the notes list and the note display.
+  if (request->query.count ("shownotestatus")) {
+    bool state = request->database_config_user ()->getShowNoteStatus ();
+    request->database_config_user ()->setShowNoteStatus (!state);
+  }
+  on_off = styles_logic_off_on_inherit_toggle_text (request->database_config_user ()->getShowNoteStatus ());
+  view.set_variable ("shownotestatus", on_off);
+
+  
   // Enable the sections with settings relevant to the user and device.
   bool resources = access_logic_privilege_view_resources (webserver_request);
   if (resources) view.enable_zone ("resources");
