@@ -77,11 +77,11 @@ string public_comment (void * webserver_request)
   }
   
   
-  string summary = database_notes.getSummary (id);
+  string summary = database_notes.get_summary_v12 (id);
   view.set_variable ("summary", summary);
   
   
-  string content = database_notes.getContents (id);
+  string content = database_notes.get_contents_v12 (id);
   view.set_variable ("content", content);
   
   
