@@ -177,7 +177,7 @@ void setup_copy_library (const char * package)
 
 void setup_write_access ()
 {
-  vector <string> folders = {"exports", "git", "revisions", "dyncss", "databases", "bibles", "downloads", "fonts", "logbook", filter_url_temp_dir ()};
+  vector <string> folders = {"exports", "git", "revisions", "dyncss", "databases", "bibles", "fonts", "logbook", filter_url_temp_dir ()};
   for (auto folder : folders) {
     string path = filter_url_create_root_path (folder);
     if (!filter_url_get_write_permission (path)) {
@@ -255,7 +255,7 @@ void setup_initialize_data ()
   database_modifications.create ();
   config_globals_setup_message = "notes";
   Database_Notes database_notes (&request);
-  database_notes.create ();
+  database_notes.create_v12 ();
   config_globals_setup_message = "state";
   Database_State::create ();
   config_globals_setup_message = "login";
