@@ -24,7 +24,7 @@
 #include <config/libraries.h>
 
 
-void sprint_burndown (string bible, bool email);
+void sprint_burndown (string bible, int manualyear, int manualmonth);
 string sprint_create_burndown_chart (string bible, int year, int month);
 
 
