@@ -157,9 +157,47 @@ void webserver_process_request (int connfd, string clientaddress)
           
           // Send response to browser.
           const char * output = request.reply.c_str();
-          // The C function strlen () fails on null characters in the reply, so take string::size()
+          // The C function strlen () fails on null characters in the reply, so use string::size() instead.
           size_t length = request.reply.size ();
-          send(connfd, output, length, 0);
+          send (connfd, output, length, 0);
+          
+          // When streaming a file, copy the file's contents straight from disk to the network file descriptor.
+          // Do not load the entire file into memory.
+          // This enables large file transfers on low-memory devices.
+          // Also handle cases that the requested file does not exist.
+          // So the number of bytes read should be larger than zero, not unequal to zero.
+          // In the case of != 0, it falls in an endless loop, because -1 indicates failure.
+          if (!request.stream_file.empty ()) {
+            int filefd =
+#ifdef HAVE_WINDOWS
+            _open
+#else
+            open
+#endif
+            (request.stream_file.c_str(), O_RDONLY);
+            unsigned char buffer [1024];
+            int bytecount;
+            do {
+              bytecount =
+#ifdef HAVE_WINDOWS
+              _read
+#else
+              read
+#endif
+              (filefd, buffer, 1024);
+              if (bytecount > 0) {
+                int sendbytes = send (connfd, (const char *)buffer, bytecount, 0);
+                (void) sendbytes;
+              }
+            }
+            while (bytecount > 0);
+#ifdef HAVE_WINDOWS
+            _close
+#else
+            close
+#endif
+            (filefd);
+          }
         }
       }
     }
@@ -596,6 +634,61 @@ void secure_webserver_process_request (mbedtls_ssl_config * conf, mbedtls_net_co
         }
       }
 
+      // When streaming a file, copy file contents straight from disk to the network file descriptor.
+      // Do not load the entire file into memory.
+      // This enables large file transfers on low-memory devices.
+      if (!request.stream_file.empty ()) {
+        int filefd =
+#ifdef HAVE_WINDOWS
+        _open
+#else
+        open
+#endif
+        (request.stream_file.c_str(), O_RDONLY);
+        unsigned char buffer [1024];
+        int bytecount;
+        do {
+          bytecount =
+#ifdef HAVE_WINDOWS
+          _read
+#else
+          read
+#endif
+          (filefd, buffer, 1024);
+          int len = bytecount;
+          const unsigned char * buf = (const unsigned char *) &buffer;
+          while (connection_healthy && (len > 0)) {
+            // Function
+            // int ret = mbedtls_ssl_write (&ssl, buf, len)
+            // will do partial writes in some cases.
+            // If the return value is non-negative but less than length,
+            // the function must be called again with updated arguments:
+            // buf + ret, len - ret
+            // until it returns a value equal to the last 'len' argument.
+            ret = mbedtls_ssl_write (&ssl, buf, len);
+            if (ret > 0) {
+              buf += ret;
+              len -= ret;
+            } else {
+              // When it returns MBEDTLS_ERR_SSL_WANT_WRITE/READ,
+              // it must be called later with the *same* arguments,
+              // until it returns a positive value.
+              if (ret == MBEDTLS_ERR_SSL_WANT_READ) continue;
+              if (ret == MBEDTLS_ERR_SSL_WANT_WRITE) continue;
+              filter_url_display_mbed_tls_error (ret, NULL, true);
+              connection_healthy = false;
+            }
+          }
+        }
+        while (bytecount > 0);
+#ifdef HAVE_WINDOWS
+        _close
+#else
+        close
+#endif
+        (filefd);
+      }
+      
       // Close SSL/TLS connection.
       if (connection_healthy) {
         while ((ret = mbedtls_ssl_close_notify (&ssl)) < 0) {
@@ -679,7 +772,7 @@ void https_server ()
   if (ret != 0) filter_url_display_mbed_tls_error (ret, NULL, true);
 
   // Seed the random number generator.
-  const char *pers = "Bibledit Cloud";
+  const char *pers = "Cloud";
   ret = mbedtls_ctr_drbg_seed( &ctr_drbg, mbedtls_entropy_func, &entropy, (const unsigned char *) pers, strlen (pers));
   if (ret != 0) {
     filter_url_display_mbed_tls_error (ret, NULL, true);
